@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2015  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2020  Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -19,10 +19,10 @@
 #include "stats.h"
 #include "tsdl.h"
 
-#define ADIF_STR(iname,item) if (strlen(item)) g_string_sprintfa(gs,"<%s:%d>%s  ",iname, (int)strlen(item),safe_strncpy0(s,item,1024))
-#define ADIF_STR_UC(iname,item) if (strlen(item)) g_string_sprintfa(gs,"<%s:%d>%s  ",iname,(int)strlen(item),z_str_uc(safe_strncpy0(s,item,1024)))
-#define ADIF_DATE(iname,item) if (strlen(item)) g_string_sprintfa(gs,"<%s:%d>%s  ",iname, (int)strlen(item),safe_strncpy0(s,item,1024))
-#define ADIF_INT(iname,item) sprintf(s,"%d",item); g_string_sprintfa(gs,"<%s:%d>%s  ",iname, (int)strlen(s),s)
+#define ADIF_STR(iname,item) if (strlen(item)) g_string_append_printf(gs,"<%s:%d>%s  ",iname, (int)strlen(item),safe_strncpy0(s,item,1024))
+#define ADIF_STR_UC(iname,item) if (strlen(item)) g_string_append_printf(gs,"<%s:%d>%s  ",iname,(int)strlen(item),z_str_uc(safe_strncpy0(s,item,1024)))
+#define ADIF_DATE(iname,item) if (strlen(item)) g_string_append_printf(gs,"<%s:%d>%s  ",iname, (int)strlen(item),safe_strncpy0(s,item,1024))
+#define ADIF_INT(iname,item) sprintf(s,"%d",item); g_string_append_printf(gs,"<%s:%d>%s  ",iname, (int)strlen(s),s)
 
 
 static gchar *convert_lt(gchar *s){
@@ -45,51 +45,51 @@ static int write_adif_header(struct band *b, struct config_band *confb, FILE *f)
     }
     
     gs = g_string_sized_new(1024);
-    g_string_sprintfa(gs, "Created by TUCNAK-%s ver. %s\r\n", Z_PLATFORM, VERSION_STRING);
-    g_string_sprintfa(gs, "TName=%s\r\n", safe_strncpy0(s, ctest->tname, 69));
+    g_string_append_printf(gs, "Created by TUCNAK-%s ver. %s\r\n", Z_PLATFORM, VERSION_STRING);
+    g_string_append_printf(gs, "TName=%s\r\n", safe_strncpy0(s, ctest->tname, 69));
     if (!b->qsos->len)
-        g_string_sprintfa(gs, "TDate=%s;%s\r\n", ctest->cdate, ctest->cdate); 
+        g_string_append_printf(gs, "TDate=%s;%s\r\n", ctest->cdate, ctest->cdate); 
     else
-        g_string_sprintfa(gs, "TDate=%d;%d\r\n", b->stats->first_date, b->stats->last_date); 
-    g_string_sprintfa(gs, "PCall=%s\r\n", z_str_uc(safe_strncpy0(s, ctest->pcall, 69)));
-    g_string_sprintfa(gs, "PWWLo=%s\r\n", z_str_uc(safe_strncpy0(s, ctest->pwwlo, 69)));
-    g_string_sprintfa(gs, "PExch=%s\r\n", z_str_uc(safe_strncpy0(s, ctest->pexch, 69)));
-    g_string_sprintfa(gs, "PAdr1=%s\r\n",    safe_strncpy0(s, ctest->padr1, 69));
-    g_string_sprintfa(gs, "PAdr2=%s\r\n",    safe_strncpy0(s, ctest->padr2, 69));
-    g_string_sprintfa(gs, "PSect=%s\r\n", psect);
-/*    g_string_sprintfa(gs, "PBand=%s\r\n", b->pband);*/
-    g_string_sprintfa(gs, "PClub=%s\r\n", z_str_uc(safe_strncpy0(s, ctest->pclub, 69)));
-    g_string_sprintfa(gs, "RName=%s\r\n",    safe_strncpy0(s, ctest->rname, 69));
-    g_string_sprintfa(gs, "RCall=%s\r\n", z_str_uc(safe_strncpy0(s, ctest->rcall, 69)));
-    g_string_sprintfa(gs, "RAdr1=%s\r\n",    safe_strncpy0(s, ctest->radr1, 69));
-    g_string_sprintfa(gs, "RAdr2=%s\r\n",    safe_strncpy0(s, ctest->radr2, 69));
-    g_string_sprintfa(gs, "RPoCo=%s\r\n",    safe_strncpy0(s, ctest->rpoco, 69));
-    g_string_sprintfa(gs, "RCity=%s\r\n",    safe_strncpy0(s, ctest->rcity, 69));
-    g_string_sprintfa(gs, "RCoun=%s\r\n",    safe_strncpy0(s, ctest->rcoun, 69));
-    g_string_sprintfa(gs, "RPhon=%s\r\n",    safe_strncpy0(s, ctest->rphon, 69));
-    g_string_sprintfa(gs, "RHBBS=%s\r\n",    safe_strncpy0(s, ctest->rhbbs, 69));
-/*    g_string_sprintfa(gs, "MOpe1=%s\r\n", z_str_uc(safe_strncpy0(s, b->mope1, 69)));
-    g_string_sprintfa(gs, "MOpe2=%s\r\n", z_str_uc(safe_strncpy0(s, b->mope2, 69)));
-    g_string_sprintfa(gs, "STXEq=%s\r\n",    safe_strncpy0(s, b->stxeq, 69));
-    g_string_sprintfa(gs, "SPowe=%s\r\n",    safe_strncpy0(s, b->spowe, 69));
-    g_string_sprintfa(gs, "SRXEq=%s\r\n",    safe_strncpy0(s, b->srxeq, 69));
-    g_string_sprintfa(gs, "SAnte=%s\r\n",    safe_strncpy0(s, b->sante, 69));
-    g_string_sprintfa(gs, "SAntH=%s\r\n",    safe_strncpy0(s, b->santh, 69));
-    g_string_sprintfa(gs, "CQSOs=%d;%d\r\n",    b->stats->nqsos, b->bandmulti);         
-    g_string_sprintfa(gs, "CQSOP=%d\r\n",       b->stats->nqsop);            
-    g_string_sprintfa(gs, "CWWLs=%d;%d;%d\r\n", g_hash_table_size(b->stats->wwls),  ctest->wwlbonu, ctest->wwlmult==0 ? 1 : ctest->wwlmult);  
-    g_string_sprintfa(gs, "CWWLB=%d\r\n",       g_hash_table_size(b->stats->wwls) * ctest->wwlbonu);
-    g_string_sprintfa(gs, "CExcs=%d;%d;%d\r\n", g_hash_table_size(b->stats->excs),  ctest->excbonu, ctest->excmult==0 ? 1 : ctest->excmult); 
-    g_string_sprintfa(gs, "CExcB=%d\r\n",       g_hash_table_size(b->stats->excs) * ctest->excbonu);             
-    g_string_sprintfa(gs, "CDXCs=%d;%d;%d\r\n", g_hash_table_size(b->stats->dxcs),  ctest->dxcbonu, ctest->dxcmult==0 ? 1 : ctest->dxcmult); 
-    g_string_sprintfa(gs, "CDXCB=%d\r\n",       g_hash_table_size(b->stats->dxcs) * ctest->dxcbonu);
-    g_string_sprintfa(gs, "CToSc=%d\r\n",       b->stats->ntotal); 
-    g_string_sprintfa(gs, "CODXC=%s;",  z_str_uc(safe_strncpy0(s, b->stats->odxcall, 20)));
-    g_string_sprintfa(gs, "%s;%d\r\n",    z_str_uc(safe_strncpy0(s, b->stats->odxwwl,  20)), b->stats->odxqrb_int);  */
+        g_string_append_printf(gs, "TDate=%d;%d\r\n", b->stats->first_date, b->stats->last_date); 
+    g_string_append_printf(gs, "PCall=%s\r\n", z_str_uc(safe_strncpy0(s, ctest->pcall, 69)));
+    g_string_append_printf(gs, "PWWLo=%s\r\n", z_str_uc(safe_strncpy0(s, ctest->pwwlo, 69)));
+    g_string_append_printf(gs, "PExch=%s\r\n", z_str_uc(safe_strncpy0(s, ctest->pexch, 69)));
+    g_string_append_printf(gs, "PAdr1=%s\r\n",    safe_strncpy0(s, ctest->padr1, 69));
+    g_string_append_printf(gs, "PAdr2=%s\r\n",    safe_strncpy0(s, ctest->padr2, 69));
+    g_string_append_printf(gs, "PSect=%s\r\n", psect);
+/*    g_string_append_printf(gs, "PBand=%s\r\n", b->pband);*/
+    g_string_append_printf(gs, "PClub=%s\r\n", z_str_uc(safe_strncpy0(s, ctest->pclub, 69)));
+    g_string_append_printf(gs, "RName=%s\r\n",    safe_strncpy0(s, ctest->rname, 69));
+    g_string_append_printf(gs, "RCall=%s\r\n", z_str_uc(safe_strncpy0(s, ctest->rcall, 69)));
+    g_string_append_printf(gs, "RAdr1=%s\r\n",    safe_strncpy0(s, ctest->radr1, 69));
+    g_string_append_printf(gs, "RAdr2=%s\r\n",    safe_strncpy0(s, ctest->radr2, 69));
+    g_string_append_printf(gs, "RPoCo=%s\r\n",    safe_strncpy0(s, ctest->rpoco, 69));
+    g_string_append_printf(gs, "RCity=%s\r\n",    safe_strncpy0(s, ctest->rcity, 69));
+    g_string_append_printf(gs, "RCoun=%s\r\n",    safe_strncpy0(s, ctest->rcoun, 69));
+    g_string_append_printf(gs, "RPhon=%s\r\n",    safe_strncpy0(s, ctest->rphon, 69));
+    g_string_append_printf(gs, "RHBBS=%s\r\n",    safe_strncpy0(s, ctest->rhbbs, 69));
+/*    g_string_append_printf(gs, "MOpe1=%s\r\n", z_str_uc(safe_strncpy0(s, b->mope1, 69)));
+    g_string_append_printf(gs, "MOpe2=%s\r\n", z_str_uc(safe_strncpy0(s, b->mope2, 69)));
+    g_string_append_printf(gs, "STXEq=%s\r\n",    safe_strncpy0(s, b->stxeq, 69));
+    g_string_append_printf(gs, "SPowe=%s\r\n",    safe_strncpy0(s, b->spowe, 69));
+    g_string_append_printf(gs, "SRXEq=%s\r\n",    safe_strncpy0(s, b->srxeq, 69));
+    g_string_append_printf(gs, "SAnte=%s\r\n",    safe_strncpy0(s, b->sante, 69));
+    g_string_append_printf(gs, "SAntH=%s\r\n",    safe_strncpy0(s, b->santh, 69));
+    g_string_append_printf(gs, "CQSOs=%d;%d\r\n",    b->stats->nqsos, b->bandmulti);         
+    g_string_append_printf(gs, "CQSOP=%d\r\n",       b->stats->nqsop);            
+    g_string_append_printf(gs, "CWWLs=%d;%d;%d\r\n", g_hash_table_size(b->stats->wwls),  ctest->wwlbonu, ctest->wwlmult==0 ? 1 : ctest->wwlmult);  
+    g_string_append_printf(gs, "CWWLB=%d\r\n",       g_hash_table_size(b->stats->wwls) * ctest->wwlbonu);
+    g_string_append_printf(gs, "CExcs=%d;%d;%d\r\n", g_hash_table_size(b->stats->excs),  ctest->excbonu, ctest->excmult==0 ? 1 : ctest->excmult); 
+    g_string_append_printf(gs, "CExcB=%d\r\n",       g_hash_table_size(b->stats->excs) * ctest->excbonu);             
+    g_string_append_printf(gs, "CDXCs=%d;%d;%d\r\n", g_hash_table_size(b->stats->dxcs),  ctest->dxcbonu, ctest->dxcmult==0 ? 1 : ctest->dxcmult); 
+    g_string_append_printf(gs, "CDXCB=%d\r\n",       g_hash_table_size(b->stats->dxcs) * ctest->dxcbonu);
+    g_string_append_printf(gs, "CToSc=%d\r\n",       b->stats->ntotal); 
+    g_string_append_printf(gs, "CODXC=%s;",  z_str_uc(safe_strncpy0(s, b->stats->odxcall, 20)));
+    g_string_append_printf(gs, "%s;%d\r\n",    z_str_uc(safe_strncpy0(s, b->stats->odxwwl,  20)), b->stats->odxqrb_int);  */
     convert_lt(gs->str);
     strcpy(dummy,"1.00");
     ADIF_STR("adif_ver",dummy);
-    g_string_sprintfa(gs, "<eoh>\r\n");
+    g_string_append_printf(gs, "<eoh>\r\n");
     ret=fprintf(f, "%s", gs->str) != gs->len;
     g_string_free(gs, TRUE);
     
@@ -165,12 +165,12 @@ static int write_adif_qsos(struct band *b, struct config_band *confb, FILE *f){
         
         if (q->qrg){
             sprintf(s,"%d.%06d",(int)(q->qrg/1000000.0), (int)fmod(q->qrg, 1000000.0)); 
-            g_string_sprintfa(gs,"<%s:%d>%s  ", "FREQ", (int)strlen(s),s);
+            g_string_append_printf(gs,"<%s:%d>%s  ", "FREQ", (int)strlen(s),s);
         }
             
         
-        g_string_sprintfa(gs, "<eor>\r\n");
-        /*g_string_sprintfa(gs, "%s\r\n", gs->str);*/
+        g_string_append_printf(gs, "<eor>\r\n");
+        /*g_string_append_printf(gs, "%s\r\n", gs->str);*/
     }
     
     ret=fprintf(f, "%s", gs->str) != gs->len;
