@@ -1,7 +1,7 @@
 
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2015  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2020  Ladislav Vaiz <ok1zia@nagano.cz>
     and authors of web browser Links 0.96
 
     This program is free software; you can redistribute it and/or
@@ -1746,9 +1746,9 @@ void errbox(char *text, int errcode, ...){
     if (errcode){
         GString *gs = g_string_new("");
         g_string_append_vprintf(gs, text, l);
-        g_string_sprintfa(gs, "\n");
+        g_string_append_printf(gs, "\n");
         z_strerror(gs, errcode);
-        g_string_sprintfa(gs, " (%d)", errcode);
+        g_string_append_printf(gs, " (%d)", errcode);
         g_snprintf(str, 1024, "%s", gs->str);
         g_string_free(gs, TRUE);
     }else{
