@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2015  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2020  Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or 
     modify it under the terms of the GNU General Public License
@@ -1330,7 +1330,7 @@ gchar *convert_esc(gchar *format, int *undef, int flags, time_t now){
                 break; 
             case 's': 
 #ifdef HAVE_SNDFILE
-                g_string_sprintfa(gs, "%d", gssbd->serno);
+                g_string_append_printf(gs, "%d", gssbd->serno);
 #endif
                 break;
             case 't':
