@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2015  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2020  Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -259,9 +259,13 @@ int load_dw_from_mem(struct dw *dw, const char *file, const long int len){
            if (!zfile_mgets(pref,  file, &pos, len, 1)) goto abort;
         }while (pref->len==0);
         
+		/*if (pref->str[0] == 'E' && pref->str[1] == 'A'){
+			int a = 1;
+		} */
+
         dxc = strtok_r(pref->str, DW_DELIM, &token_ptr);
         if (!dxc) continue;
-        add_pd(dw, dxc, dxc);
+        //add_pd(dw, dxc, dxc); //must be in cty.dat
         
         while ((prefix=strtok_r(NULL, DW_DELIM, &token_ptr))!=NULL){
             add_pd(dw, prefix, dxc);
@@ -486,12 +490,44 @@ void read_dw_files(struct dw *dw){
 
 
 struct dw_item *get_dw_item_by_call(struct dw *dw, const char *call){
-    char dxcc[25];
+	char dxcc[25];
+	char pref[25];
+	struct dw_item *dwi = NULL;
 	
+	get_pref(pref, call);
+	dwi = g_hash_table_lookup(dw->dw, pref); // prefix specific entry (EA1)
+	if (dwi != NULL) return dwi;
+
     get_dxcc(dw, dxcc, call);
-    return (struct dw_item *)g_hash_table_lookup(dw->dw, dxcc);
+	dwi = g_hash_table_lookup(dw->dw, dxcc);
+	return dwi; 
 }
 
+struct dw_item *get_dw_base_item_by_call(struct dw *dw, const char *call){
+	char dxcc[25];
+	char pref[25];
+	GString *call2;
+	struct dw_item *dwi = NULL;
+
+	call2 = g_string_new(call);
+	get_dxcc(dw, dxcc, call);
+	if (strlen(dxcc) == strlen(call)) {
+		g_string_free(call2, TRUE);
+		return NULL;
+	}
+
+	// SK6DK -> SM6DK
+	g_string_erase(call2, 0, strlen(dxcc));
+	g_string_insert(call2, 0, dxcc); 
+
+	get_pref(pref, call2->str);
+	g_string_free(call2, TRUE);
+	dwi = g_hash_table_lookup(dw->dw, pref); // prefix specific entry (EA1)
+	if (dwi != NULL) return dwi;
+
+	dwi = g_hash_table_lookup(dw->dw, dxcc);
+	return dwi;
+}
 
 int wwl_is_ok_by_call(struct dw *dw, gchar *wwl, gchar *call){
     struct dw_item *dxci;
@@ -499,20 +535,23 @@ int wwl_is_ok_by_call(struct dw *dw, gchar *wwl, gchar *call){
     
     if (!wwl || !call) return 1;
     
-    /*dbg("dxcc=%s\n", dxcc);*/
-            
     dxci = get_dw_item_by_call(dw, call);
-    if (!dxci) {
-/*        dbg("can't find dxcc (%s) for call %s \n", dxcc, call);*/
-        return 0;
-    }
+	if (dxci) {
+		safe_strncpy(swwl, wwl, 5);
+		if (g_hash_table_lookup(dxci->wwls, swwl)){
+			return 1;
+		}
+	}
+
+	// SM6 -> SM
+	dxci = get_dw_base_item_by_call(dw, call);
+	if (dxci) {
+		safe_strncpy(swwl, wwl, 5);
+		if (g_hash_table_lookup(dxci->wwls, swwl)){
+			return 1;
+		}
+	}
 
-    safe_strncpy(swwl, wwl, 5);
-    if (g_hash_table_lookup(dxci->wwls, swwl)){
-/*       dbg("is OK\n"); */
-       return 1; 
-    }
-/*    dbg("loc not found\n");*/
     return 0;
 }
 
@@ -593,9 +632,9 @@ int get_susp_loc(struct cw *cw, struct dw *dw, gchar *call, gchar *wwl){
 
 #define ADDQSO if (!err) { \
     if (qso->time_str){ \
-        g_string_sprintfa(gs, "%s %s %c%c.%c%c\n", qso->callsign?qso->callsign:"?", qso->locator?qso->locator:"?", qso->time_str[0], qso->time_str[1], qso->time_str[2], qso->time_str[3]); \
+        g_string_append_printf(gs, "%s %s %c%c.%c%c\n", qso->callsign?qso->callsign:"?", qso->locator?qso->locator:"?", qso->time_str[0], qso->time_str[1], qso->time_str[2], qso->time_str[3]); \
     }else{ \
-        g_string_sprintfa(gs, "%s %s\n", qso->callsign?qso->callsign:"?", qso->locator?qso->locator:"?"); \
+        g_string_append_printf(gs, "%s %s\n", qso->callsign?qso->callsign:"?", qso->locator?qso->locator:"?"); \
     }err=1;}
 
 enum suspcall qso_info(struct qso *qso, GString *gs, GString *gs2){
@@ -699,7 +738,7 @@ enum suspcall qso_info(struct qso *qso, GString *gs, GString *gs2){
             if (find_wwl_by_call_newer(cw, s, cw->minstamp)) {
 				if (gs){
 					ADDQSO;
-					g_string_sprintfa(gs, VTEXT(T_CALL_WITHOUT_D), k, k);
+					g_string_append_printf(gs, VTEXT(T_CALL_WITHOUT_D), k, k);
 				}
                 if (ret < SUSP_WARN) ret = SUSP_WARN;
             }
@@ -721,7 +760,7 @@ enum suspcall qso_info(struct qso *qso, GString *gs, GString *gs2){
         if (gs2->len>0){
 			if (gs){
 				ADDQSO;
-				g_string_sprintfa(gs, VTEXT(T_OTHER_SIMILAR_CALL_KNOWN), gs2->str);
+				g_string_append_printf(gs, VTEXT(T_OTHER_SIMILAR_CALL_KNOWN), gs2->str);
 			}
             if (ret < SUSP_WARN) ret = SUSP_WARN;
         }
@@ -745,7 +784,7 @@ enum suspcall qso_info(struct qso *qso, GString *gs, GString *gs2){
                 if (strcmp(q->callsign, qso->callsign) != 0){ 
 					if (gs){
 						ADDQSO;
-						g_string_sprintfa(gs, VTEXT(T_CALL_ON_BAND_S), b->bandname, q->callsign);
+						g_string_append_printf(gs, VTEXT(T_CALL_ON_BAND_S), b->bandname, q->callsign);
 					}
                     if (ret < SUSP_WARN) ret = SUSP_WARN;
                 }
@@ -753,7 +792,7 @@ enum suspcall qso_info(struct qso *qso, GString *gs, GString *gs2){
                 if (qso->locator != NULL && strcmp(q->locator, qso->locator) != 0){
 					if (gs){
 						ADDQSO;
-						g_string_sprintfa(gs, VTEXT(T_LOCATOR_ON_BAND), b->bandname, q->locator);
+						g_string_append_printf(gs, VTEXT(T_LOCATOR_ON_BAND), b->bandname, q->locator);
 					}
                     if (ret < SUSP_WARN) ret = SUSP_WARN;
                 }
@@ -777,28 +816,28 @@ void menu_qso_check(void *arg){
 
     gs=g_string_sized_new(10000);
     gs2=g_string_sized_new(1000);
-    g_string_sprintf(gs,  "%s", VTEXT(T_QSO_CHECK_LIST));
-    g_string_sprintfa(gs, " *************************\n");
-    g_string_sprintfa(gs, "\n\n");
-    g_string_sprintfa(gs, VTEXT(T_CALL_SN), ctest->pcall);
-    g_string_sprintfa(gs, VTEXT(T_CONTEST_SN), ctest->tname);
-    g_string_sprintfa(gs, VTEXT(T_DATE_SN), ctest->tdate);
-    g_string_sprintfa(gs, "\n\n");
+    g_string_printf(gs,  "%s", VTEXT(T_QSO_CHECK_LIST));
+    g_string_append_printf(gs, " *************************\n");
+    g_string_append_printf(gs, "\n\n");
+    g_string_append_printf(gs, VTEXT(T_CALL_SN), ctest->pcall);
+    g_string_append_printf(gs, VTEXT(T_CONTEST_SN), ctest->tname);
+    g_string_append_printf(gs, VTEXT(T_DATE_SN), ctest->tdate);
+    g_string_append_printf(gs, "\n\n");
 
     for (i=0;i<ctest->bands->len;i++){
         band = (struct band *)g_ptr_array_index(ctest->bands, i);
 		progress(VTEXT(T_CHECKING_S), band->bandname);
-        g_string_sprintfa(gs, VTEXT(T_BAND_C_SN), band->bandchar, band->pband);
-        g_string_sprintfa(gs, " ********************\n");
+        g_string_append_printf(gs, VTEXT(T_BAND_C_SN), band->bandchar, band->pband);
+        g_string_append_printf(gs, " ********************\n");
         for (j=0;j<band->qsos->len;j++){
             qso = (struct qso *)g_ptr_array_index(band->qsos, j);
             ret=qso_info(qso, gs, gs2);
-            if (ret) g_string_sprintfa(gs, "\n");
+            if (ret) g_string_append_printf(gs, "\n");
             if (ret>=0) qso->suspcall1=(enum suspcall)ret;
         }
     }
 
-    g_string_sprintfa(gs, "\n\nEOF\n");
+    g_string_append_printf(gs, "\n\nEOF\n");
 
     filename = g_strdup_printf("%s/qsocheck.txt", ctest->directory);
 	z_wokna(filename);
@@ -923,7 +962,7 @@ void call_info(void *arg){
     if (gs2->len>0){
         g_string_append(gs, gs2->str);
     }else{
-        g_string_sprintfa(gs, VTEXT(T_CW_NOT_FOUND), qso->callsign);
+        g_string_append_printf(gs, VTEXT(T_CW_NOT_FOUND), qso->callsign);
     }
 
     /* wkd */
@@ -938,16 +977,16 @@ void call_info(void *arg){
 
     /* qrv */
     qi = qrv_get(qrv, qso->callsign);
-    g_string_sprintfa(gs, "QRV: ");
+    g_string_append_printf(gs, "QRV: ");
     if (qi){
-//        g_string_sprintfa(gs, " %s", qi->wwl);
+//        g_string_append_printf(gs, " %s", qi->wwl);
         if (aband){
-            g_string_sprintfa(gs, " %dx", qi->wkd[aband->bandchar - 'a']);
+            g_string_append_printf(gs, " %dx", qi->wkd[aband->bandchar - 'a']);
         }
         if (qi->kst_time != 0){
             struct tm utc;
             gmtime_r(&qi->kst_time, &utc);
-            g_string_sprintfa(gs, " %2d:%02d", utc.tm_hour, utc.tm_min);
+            g_string_append_printf(gs, " %2d:%02d", utc.tm_hour, utc.tm_min);
         }
     }else{
         g_string_append(gs, VTEXT(T_0X_NOT_IN_DB));
@@ -957,9 +996,9 @@ void call_info(void *arg){
     /* namedb */
     c=find_name_by_call(namedb, qso->callsign);
     if (c){
-        g_string_sprintfa(gs, VTEXT(T_NAME_IS), qso->callsign, c);
+        g_string_append_printf(gs, VTEXT(T_NAME_IS), qso->callsign, c);
     }else{
-        g_string_sprintfa(gs, VTEXT(T_NAME_UNKNOWN), qso->callsign);
+        g_string_append_printf(gs, VTEXT(T_NAME_UNKNOWN), qso->callsign);
     }
 
 	/* dxcc */
@@ -967,7 +1006,7 @@ void call_info(void *arg){
 	if (dwi){
 		char dxcc[32];
 		get_dxcc(dw, dxcc, qso->callsign);
-		g_string_sprintfa(gs, "DXCC: %s %s\n", dxcc, dwi->dxcname);
+		g_string_append_printf(gs, "DXCC: %s %s\n", dxcc, dwi->dxcname);
 	}
 
 	txt = g_strdup(gs->str);
@@ -998,13 +1037,13 @@ x:;
 }
 
 
-gchar *find_wwl_by_dxc(struct dw *dw,  gchar *dxc){
+gchar *find_wwl_by_dxc_or_pref(struct dw *dw, gchar *call){
     struct dw_item *dxci;
 
-    if (!dxc) return dw_next;
+    if (!call) return dw_next;
     dw_next = NULL;
     
-    dxci = (struct dw_item *)g_hash_table_lookup(dw->dw, dxc);
+	dxci = get_dw_item_by_call(dw, call);
     if (!dxci) return NULL;
 
     dw_next = dxci->wwl1;
@@ -1085,7 +1124,7 @@ found:;
     return buf;  
 }
 
-char *get_pref(char *buf, char *call){ 
+char *get_pref(char *buf, const char *call){ 
     char *c0, *c1, *c2;
     
     c0=c1=c2=NULL;
