@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2015  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2020  Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -52,7 +52,7 @@ void add_qso_str1(GString *gs, struct qso *q, struct band *b){
         g_string_append(gs, z_str_uc(safe_strncpy0(s, q->callsign, 20)));
     g_string_append_c(gs, ';');
    
-    g_string_sprintfa(gs, "%d", q->mode);
+    g_string_append_printf(gs, "%d", q->mode);
     g_string_append_c(gs, ';');
     
     g_string_append(gs, z_str_uc(safe_strncpy0(s, q->rsts, 6)));
@@ -78,7 +78,7 @@ void add_qso_str1(GString *gs, struct qso *q, struct band *b){
 void add_qso_str2(GString *gs, struct qso *q, struct band *b){
     
     if (!q->dupe && !q->error && strcasecmp(q->callsign, "ERROR")!=0)
-        g_string_sprintfa(gs, "%d;", q->qsop/* * b->bandmulti*/);
+        g_string_append_printf(gs, "%d;", q->qsop/* * b->bandmulti*/);
     else{
         g_string_append(gs, "0;");
         dump_qso(q, "write_edi_qsos");
@@ -105,7 +105,7 @@ void add_qso_str3(GString *gs, struct qso *q, struct band *b){
     g_string_append(gs, fixsemi(q->operator_));
     g_string_append_c(gs, ';');
     
-    g_string_sprintfa(gs, "%d;", (int)q->stamp);
+    g_string_append_printf(gs, "%d;", (int)q->stamp);
    
     if (q->error) g_string_append(gs, q->callsign);
     g_string_append_c(gs, ';');
@@ -117,9 +117,9 @@ void add_qso_str3(GString *gs, struct qso *q, struct band *b){
     safe_strncpy0(s, q->remark, MAX_STR_LEN);
     g_string_append(gs, fixsemi(s));
     
-    g_string_sprintfa(gs, ";%d", q->ser_id);
+    g_string_append_printf(gs, ";%d", q->ser_id);
     
-    g_string_sprintfa(gs, ";%1.0f", q->qrg);
+    g_string_append_printf(gs, ";%1.0f", q->qrg);
 }
 
 
@@ -145,49 +145,49 @@ static int write_edi_header(struct band *b, struct config_band *confb, FILE *f){
 	int qsomult;
     
     gs = g_string_sized_new(1024);
-    g_string_sprintfa(gs, "[REG1TEST;1]\r\n");
-    g_string_sprintfa(gs, "TName=%s\r\n", safe_strncpy0(s, ctest->tname, 69));
+    g_string_append_printf(gs, "[REG1TEST;1]\r\n");
+    g_string_append_printf(gs, "TName=%s\r\n", safe_strncpy0(s, ctest->tname, 69));
     if (!b->qsos->len)
-        g_string_sprintfa(gs, "TDate=%s;%s\r\n", ctest->cdate, ctest->cdate); 
+        g_string_append_printf(gs, "TDate=%s;%s\r\n", ctest->cdate, ctest->cdate); 
     else
-        g_string_sprintfa(gs, "TDate=%d;%d\r\n", b->stats->first_date, b->stats->last_date); 
-    g_string_sprintfa(gs, "PCall=%s\r\n", z_str_uc(safe_strncpy0(s, ctest->pcall, 69)));
-    g_string_sprintfa(gs, "PWWLo=%s\r\n", z_str_uc(safe_strncpy0(s, ctest->pwwlo, 69)));
-	g_string_sprintfa(gs, "PExch=%s\r\n", z_str_uc(safe_strncpy0(s, ctest->pexch, MAX_EXC_LEN+1)));
-    g_string_sprintfa(gs, "PAdr1=%s\r\n",    safe_strncpy0(s, ctest->padr1, 69));
-    g_string_sprintfa(gs, "PAdr2=%s\r\n",    safe_strncpy0(s, ctest->padr2, 69));
-	g_string_sprintfa(gs, "PSect=%s\r\n", get_psect_str(b));
-    g_string_sprintfa(gs, "PBand=%s\r\n", b->pband);
-    g_string_sprintfa(gs, "PClub=%s\r\n", z_str_uc(safe_strncpy0(s, ctest->pclub, 69)));
-    g_string_sprintfa(gs, "RName=%s\r\n",    safe_strncpy0(s, ctest->rname, 69));
-    g_string_sprintfa(gs, "RCall=%s\r\n", z_str_uc(safe_strncpy0(s, ctest->rcall, 69)));
-    g_string_sprintfa(gs, "RAdr1=%s\r\n",    safe_strncpy0(s, ctest->radr1, 69));
-    g_string_sprintfa(gs, "RAdr2=%s\r\n",    safe_strncpy0(s, ctest->radr2, 69));
-    g_string_sprintfa(gs, "RPoCo=%s\r\n",    safe_strncpy0(s, ctest->rpoco, 69));
-    g_string_sprintfa(gs, "RCity=%s\r\n",    safe_strncpy0(s, ctest->rcity, 69));
-    g_string_sprintfa(gs, "RCoun=%s\r\n",    safe_strncpy0(s, ctest->rcoun, 69));
-    g_string_sprintfa(gs, "RPhon=%s\r\n",    safe_strncpy0(s, ctest->rphon, 69));
-    g_string_sprintfa(gs, "RHBBS=%s\r\n",    safe_strncpy0(s, ctest->rhbbs, 69));
-    g_string_sprintfa(gs, "MOpe1=%s\r\n", z_str_uc(safe_strncpy0(s, b->mope1, 69)));
-    g_string_sprintfa(gs, "MOpe2=%s\r\n", z_str_uc(safe_strncpy0(s, b->mope2, 69)));
-    g_string_sprintfa(gs, "STXEq=%s\r\n",    safe_strncpy0(s, b->stxeq, 69));
-    g_string_sprintfa(gs, "SPowe=%s\r\n",    safe_strncpy0(s, b->spowe, 69));
-    g_string_sprintfa(gs, "SRXEq=%s\r\n",    safe_strncpy0(s, b->srxeq, 69));
-    g_string_sprintfa(gs, "SAnte=%s\r\n",    safe_strncpy0(s, b->sante, 69));
-    g_string_sprintfa(gs, "SAntH=%s\r\n",    safe_strncpy0(s, b->santh, 69));
+        g_string_append_printf(gs, "TDate=%d;%d\r\n", b->stats->first_date, b->stats->last_date); 
+    g_string_append_printf(gs, "PCall=%s\r\n", z_str_uc(safe_strncpy0(s, ctest->pcall, 69)));
+    g_string_append_printf(gs, "PWWLo=%s\r\n", z_str_uc(safe_strncpy0(s, ctest->pwwlo, 69)));
+	g_string_append_printf(gs, "PExch=%s\r\n", z_str_uc(safe_strncpy0(s, ctest->pexch, MAX_EXC_LEN+1)));
+    g_string_append_printf(gs, "PAdr1=%s\r\n",    safe_strncpy0(s, ctest->padr1, 69));
+    g_string_append_printf(gs, "PAdr2=%s\r\n",    safe_strncpy0(s, ctest->padr2, 69));
+	g_string_append_printf(gs, "PSect=%s\r\n", get_psect_str(b));
+    g_string_append_printf(gs, "PBand=%s\r\n", b->pband);
+    g_string_append_printf(gs, "PClub=%s\r\n", z_str_uc(safe_strncpy0(s, ctest->pclub, 69)));
+    g_string_append_printf(gs, "RName=%s\r\n",    safe_strncpy0(s, ctest->rname, 69));
+    g_string_append_printf(gs, "RCall=%s\r\n", z_str_uc(safe_strncpy0(s, ctest->rcall, 69)));
+    g_string_append_printf(gs, "RAdr1=%s\r\n",    safe_strncpy0(s, ctest->radr1, 69));
+    g_string_append_printf(gs, "RAdr2=%s\r\n",    safe_strncpy0(s, ctest->radr2, 69));
+    g_string_append_printf(gs, "RPoCo=%s\r\n",    safe_strncpy0(s, ctest->rpoco, 69));
+    g_string_append_printf(gs, "RCity=%s\r\n",    safe_strncpy0(s, ctest->rcity, 69));
+    g_string_append_printf(gs, "RCoun=%s\r\n",    safe_strncpy0(s, ctest->rcoun, 69));
+    g_string_append_printf(gs, "RPhon=%s\r\n",    safe_strncpy0(s, ctest->rphon, 69));
+    g_string_append_printf(gs, "RHBBS=%s\r\n",    safe_strncpy0(s, ctest->rhbbs, 69));
+    g_string_append_printf(gs, "MOpe1=%s\r\n", z_str_uc(safe_strncpy0(s, b->mope1, 69)));
+    g_string_append_printf(gs, "MOpe2=%s\r\n", z_str_uc(safe_strncpy0(s, b->mope2, 69)));
+    g_string_append_printf(gs, "STXEq=%s\r\n",    safe_strncpy0(s, b->stxeq, 69));
+    g_string_append_printf(gs, "SPowe=%s\r\n",    safe_strncpy0(s, b->spowe, 69));
+    g_string_append_printf(gs, "SRXEq=%s\r\n",    safe_strncpy0(s, b->srxeq, 69));
+    g_string_append_printf(gs, "SAnte=%s\r\n",    safe_strncpy0(s, b->sante, 69));
+    g_string_append_printf(gs, "SAntH=%s\r\n",    safe_strncpy0(s, b->santh, 69));
     qsomult = ctest->qsomult;
     if (ctest->qsop_method==16) qsomult = qsomult16(b);
-	g_string_sprintfa(gs, "CQSOs=%d;%d\r\n",    b->stats->nqsos, qsomult * b->qsomultb);         
-    g_string_sprintfa(gs, "CQSOP=%d\r\n",       b->stats->nqsop);            
-    g_string_sprintfa(gs, "CWWLs=%d;%d;%d\r\n", g_hash_table_size(b->stats->wwls),  ctest->wwlbonu, ctest->wwlmult==0 ? 1 : ctest->wwlmult);  
-    g_string_sprintfa(gs, "CWWLB=%d\r\n",       g_hash_table_size(b->stats->wwls) * ctest->wwlbonu);
-    g_string_sprintfa(gs, "CExcs=%d;%d;%d\r\n", b->stats->nexcp,  ctest->excbonu, ctest->excmult==0 ? 1 : ctest->excmult); 
-    g_string_sprintfa(gs, "CExcB=%d\r\n",       g_hash_table_size(b->stats->excs) * ctest->excbonu);             
-    g_string_sprintfa(gs, "CDXCs=%d;%d;%d\r\n", g_hash_table_size(b->stats->dxcs),  ctest->dxcbonu, ctest->dxcmult==0 ? 1 : ctest->dxcmult); 
-    g_string_sprintfa(gs, "CDXCB=%d\r\n",       g_hash_table_size(b->stats->dxcs) * ctest->dxcbonu);
-    g_string_sprintfa(gs, "CToSc=%d\r\n",       b->stats->ntotal); 
-    g_string_sprintfa(gs, "CODXC=%s;",  z_str_uc(safe_strncpy0(s, b->stats->odxcall, 20)));
-    g_string_sprintfa(gs, "%s;%d\r\n",    z_str_uc(safe_strncpy0(s, b->stats->odxwwl,  20)), b->stats->odxqrb_int);  
+	g_string_append_printf(gs, "CQSOs=%d;%d\r\n",    b->stats->nqsos, qsomult * b->qsomultb);         
+    g_string_append_printf(gs, "CQSOP=%d\r\n",       b->stats->nqsop);            
+    g_string_append_printf(gs, "CWWLs=%d;%d;%d\r\n", g_hash_table_size(b->stats->wwls),  ctest->wwlbonu, ctest->wwlmult==0 ? 1 : ctest->wwlmult);  
+    g_string_append_printf(gs, "CWWLB=%d\r\n",       g_hash_table_size(b->stats->wwls) * ctest->wwlbonu);
+    g_string_append_printf(gs, "CExcs=%d;%d;%d\r\n", b->stats->nexcp,  ctest->excbonu, ctest->excmult==0 ? 1 : ctest->excmult); 
+    g_string_append_printf(gs, "CExcB=%d\r\n",       g_hash_table_size(b->stats->excs) * ctest->excbonu);             
+    g_string_append_printf(gs, "CDXCs=%d;%d;%d\r\n", g_hash_table_size(b->stats->dxcs),  ctest->dxcbonu, ctest->dxcmult==0 ? 1 : ctest->dxcmult); 
+    g_string_append_printf(gs, "CDXCB=%d\r\n",       g_hash_table_size(b->stats->dxcs) * ctest->dxcbonu);
+    g_string_append_printf(gs, "CToSc=%d\r\n",       b->stats->ntotal); 
+    g_string_append_printf(gs, "CODXC=%s;",  z_str_uc(safe_strncpy0(s, b->stats->odxcall, 20)));
+    g_string_append_printf(gs, "%s;%d\r\n",    z_str_uc(safe_strncpy0(s, b->stats->odxwwl,  20)), b->stats->odxqrb_int);  
     
     ret=fprintf(f, "%s", gs->str) != gs->len;
     g_string_free(gs, TRUE);
@@ -202,10 +202,10 @@ static int write_edi_empty_remarks(struct band *b, struct config_band *confb, FI
 
     
     gs = g_string_sized_new(100);
-    g_string_sprintfa(gs, "[Remarks]\r\n");
-    if (b->remarks && b->remarks[0]=='[') g_string_sprintfa(gs, " ");
-    g_string_sprintfa(gs, "%s", safe_strncpy0(s, b->remarks, 1024));
-    g_string_sprintfa(gs, "\r\n");                    
+    g_string_append_printf(gs, "[Remarks]\r\n");
+    if (b->remarks && b->remarks[0]=='[') g_string_append_printf(gs, " ");
+    g_string_append_printf(gs, "%s", safe_strncpy0(s, b->remarks, 1024));
+    g_string_append_printf(gs, "\r\n");                    
     
     ret=fprintf(f, "%s", gs->str) != gs->len;
     g_string_free(gs, TRUE);
@@ -222,58 +222,58 @@ static int write_edi_remarks(struct band *b, struct config_band *confb, FILE *f)
 
     gs = g_string_sized_new(1024);
     
-    g_string_sprintfa(gs, "[Remarks]\r\n");
-    if (b->remarks && b->remarks[0]=='[') g_string_sprintfa(gs, " ");
-    g_string_sprintfa(gs, "%s", safe_strncpy0(s, b->remarks, 1024));
-    g_string_sprintfa(gs, "\r\n");                    
+    g_string_append_printf(gs, "[Remarks]\r\n");
+    if (b->remarks && b->remarks[0]=='[') g_string_append_printf(gs, " ");
+    g_string_append_printf(gs, "%s", safe_strncpy0(s, b->remarks, 1024));
+    g_string_append_printf(gs, "\r\n");                    
 
-    g_string_sprintfa(gs, "[TUCNAK extension]\r\n");
-    g_string_sprintfa(gs, "default_rs=%s\r\n",  ctest->default_rs);
-    g_string_sprintfa(gs, "default_rst=%s\r\n", ctest->default_rst);
-    g_string_sprintfa(gs, "prefmult=%d\r\n", ctest->prefmult);
-    g_string_sprintfa(gs, "prefglob=%d\r\n", ctest->prefglob);
-    g_string_sprintfa(gs, "dxcbonu=%d\r\n", ctest->dxcbonu);
-    g_string_sprintfa(gs, "dxcmult=%d\r\n", ctest->dxcmult);
-    g_string_sprintfa(gs, "excused=%d\r\n", ctest->excused);
-    g_string_sprintfa(gs, "exctype=%d\r\n", ctest->exctype);
-    g_string_sprintfa(gs, "excname=%s\r\n", ctest->excname);
-    g_string_sprintfa(gs, "excbonu=%d\r\n", ctest->excbonu);
-    g_string_sprintfa(gs, "excmult=%d\r\n", ctest->excmult);
-    g_string_sprintfa(gs, "exccfm=%d\r\n",  ctest->exccfm);
-    g_string_sprintfa(gs, "qsoused=%d\r\n", ctest->qsoused);
-    g_string_sprintfa(gs, "qsomult=%d\r\n", ctest->qsomult);
-    g_string_sprintfa(gs, "qsomultb=%d\r\n", b->qsomultb);
-    g_string_sprintfa(gs, "qsoglob=%d\r\n", ctest->qsoglob);
-    g_string_sprintfa(gs, "qsop_method=%d\r\n",  ctest->qsop_method);
-    g_string_sprintfa(gs, "rstused=%d\r\n", ctest->rstused);
-    g_string_sprintfa(gs, "defrstr=%d\r\n", ctest->defrstr);
-    g_string_sprintfa(gs, "total_method=%d\r\n", ctest->total_method);
-    g_string_sprintfa(gs, "wwltype=%d\r\n", ctest->wwltype);
-    g_string_sprintfa(gs, "wwlused=%d\r\n", ctest->wwlused);
-    g_string_sprintfa(gs, "wwlbonu=%d\r\n", ctest->wwlbonu);
-    g_string_sprintfa(gs, "wwlmult=%d\r\n", ctest->wwlmult);
-    g_string_sprintfa(gs, "wwlcfm=%d\r\n", ctest->wwlcfm);
-    g_string_sprintfa(gs, "tttype=%d\r\n", ctest->tttype);
-    g_string_sprintfa(gs, "expmode=%d\r\n", ctest->expmode);
+    g_string_append_printf(gs, "[TUCNAK extension]\r\n");
+    g_string_append_printf(gs, "default_rs=%s\r\n",  ctest->default_rs);
+    g_string_append_printf(gs, "default_rst=%s\r\n", ctest->default_rst);
+    g_string_append_printf(gs, "prefmult=%d\r\n", ctest->prefmult);
+    g_string_append_printf(gs, "prefglob=%d\r\n", ctest->prefglob);
+    g_string_append_printf(gs, "dxcbonu=%d\r\n", ctest->dxcbonu);
+    g_string_append_printf(gs, "dxcmult=%d\r\n", ctest->dxcmult);
+    g_string_append_printf(gs, "excused=%d\r\n", ctest->excused);
+    g_string_append_printf(gs, "exctype=%d\r\n", ctest->exctype);
+    g_string_append_printf(gs, "excname=%s\r\n", ctest->excname);
+    g_string_append_printf(gs, "excbonu=%d\r\n", ctest->excbonu);
+    g_string_append_printf(gs, "excmult=%d\r\n", ctest->excmult);
+    g_string_append_printf(gs, "exccfm=%d\r\n",  ctest->exccfm);
+    g_string_append_printf(gs, "qsoused=%d\r\n", ctest->qsoused);
+    g_string_append_printf(gs, "qsomult=%d\r\n", ctest->qsomult);
+    g_string_append_printf(gs, "qsomultb=%d\r\n", b->qsomultb);
+    g_string_append_printf(gs, "qsoglob=%d\r\n", ctest->qsoglob);
+    g_string_append_printf(gs, "qsop_method=%d\r\n",  ctest->qsop_method);
+    g_string_append_printf(gs, "rstused=%d\r\n", ctest->rstused);
+    g_string_append_printf(gs, "defrstr=%d\r\n", ctest->defrstr);
+    g_string_append_printf(gs, "total_method=%d\r\n", ctest->total_method);
+    g_string_append_printf(gs, "wwltype=%d\r\n", ctest->wwltype);
+    g_string_append_printf(gs, "wwlused=%d\r\n", ctest->wwlused);
+    g_string_append_printf(gs, "wwlbonu=%d\r\n", ctest->wwlbonu);
+    g_string_append_printf(gs, "wwlmult=%d\r\n", ctest->wwlmult);
+    g_string_append_printf(gs, "wwlcfm=%d\r\n", ctest->wwlcfm);
+    g_string_append_printf(gs, "tttype=%d\r\n", ctest->tttype);
+    g_string_append_printf(gs, "expmode=%d\r\n", ctest->expmode);
     
-    g_string_sprintfa(gs, "bandchar=%c\r\n", b->bandchar);
-//    g_string_sprintfa(gs, "bandmulti=%d\r\n", b->bandmulti);
-    g_string_sprintfa(gs, "mode=%d\r\n", gses->mode);
-    g_string_sprintfa(gs, "operator=%s\r\n", b->operator_);
-    g_string_sprintfa(gs, "psect=%d\r\n", b->psect);
-    g_string_sprintfa(gs, "opsect=%s\r\n", b->opsect);
-    g_string_sprintfa(gs, "readonly=%d\r\n", b->readonly);
-    g_string_sprintfa(gs, "saveid=%d\r\n", b->saveid);
-	g_string_sprintfa(gs, "skedqrg=%s\r\n", b->skedqrg);
+    g_string_append_printf(gs, "bandchar=%c\r\n", b->bandchar);
+//    g_string_append_printf(gs, "bandmulti=%d\r\n", b->bandmulti);
+    g_string_append_printf(gs, "mode=%d\r\n", gses->mode);
+    g_string_append_printf(gs, "operator=%s\r\n", b->operator_);
+    g_string_append_printf(gs, "psect=%d\r\n", b->psect);
+    g_string_append_printf(gs, "opsect=%s\r\n", b->opsect);
+    g_string_append_printf(gs, "readonly=%d\r\n", b->readonly);
+    g_string_append_printf(gs, "saveid=%d\r\n", b->saveid);
+	g_string_append_printf(gs, "skedqrg=%s\r\n", b->skedqrg);
 
     for (i=0; i< b->qsos->len; i++){
         q = get_qso(b, i); 
         
-        g_string_sprintfa(gs, "qso%d=", i);
+        g_string_append_printf(gs, "qso%d=", i);
         add_qso_str3(gs, q, b);
         
-        /*g_string_sprintfa(gs, "%s\r\n",gs->str);*/
-        g_string_sprintfa(gs, "\r\n");
+        /*g_string_append_printf(gs, "%s\r\n",gs->str);*/
+        g_string_append_printf(gs, "\r\n");
     }
     
     ret=fprintf(f, "%s", gs->str) != gs->len;
@@ -291,7 +291,7 @@ static int write_edi_qsos(struct band *b, struct config_band *confb, FILE *f){
 
     gs = g_string_new("");
     
-    g_string_sprintfa(gs, "[QSORecords;%d]\r\n", b->qsos->len);
+    g_string_append_printf(gs, "[QSORecords;%d]\r\n", b->qsos->len);
     
     for (i=0; i<b->qsos->len; i++){
         q = get_qso(b, i); 
@@ -299,11 +299,11 @@ static int write_edi_qsos(struct band *b, struct config_band *confb, FILE *f){
         add_qso_str1(gs, q, b);
         add_qso_str2(gs, q, b);
         
-        g_string_sprintfa(gs, "\r\n");
-        /*g_string_sprintfa(gs, "%s\r\n", gs->str);*/
+        g_string_append_printf(gs, "\r\n");
+        /*g_string_append_printf(gs, "%s\r\n", gs->str);*/
     }
     
-    g_string_sprintfa(gs, "[END;TUCNAK-%s ver. %s]\r\n", Z_PLATFORM, VERSION);
+    g_string_append_printf(gs, "[END;TUCNAK-%s ver. %s]\r\n", Z_PLATFORM, VERSION);
     ret=fprintf(f, "%s", gs->str) != gs->len;
     g_string_free(gs, TRUE);
     
@@ -321,7 +321,7 @@ static int write_edi_unfi(struct band *b, struct config_band *confb, FILE *f){
     
     for (i=0; i<b->unfi->items->len; i++){
         c = (gchar *) g_ptr_array_index(b->unfi->items, i);
-        g_string_sprintfa(gs, "unfinished%d=%s\r\n", i, c);
+        g_string_append_printf(gs, "unfinished%d=%s\r\n", i, c);
     }
     ret=fprintf(f, "%s", gs->str) != gs->len;
     g_string_free(gs, TRUE);
@@ -341,7 +341,7 @@ static int write_edi_sked(struct band *b, struct config_band *confb, FILE *f){
     for (i=0; i<b->skeds->len; i++){
         sked = (struct sked *) g_ptr_array_index(b->skeds, i);
         zs = sked_format(sked);
-        g_string_sprintfa(gs, "sked%d=%s\r\n", i, zs->str);
+        g_string_append_printf(gs, "sked%d=%s\r\n", i, zs->str);
         zfree(zs);
     }
     ret=fprintf(f, "%s", gs->str) != gs->len;
