@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2006  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2020  Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -13,6 +13,7 @@
 
 #include "bfu.h"
 #include "fifo.h"
+#include "kst.h"
 #include "qsodb.h"
 #include "session.h"
 #include "subwin.h"
@@ -309,3 +310,56 @@ int fifo_contains(struct fifo *fifo, char *needle){
 	return 0;
 }
 
+char *fifo_call_under(struct fifo *fifo, int x, int y){
+	int i1, i2, len;
+	char call[25];
+
+	int index = fifo->items->len - fifo->h + y;
+	if (index < 0) return NULL;
+	if (index >= fifo->items->len) return NULL;
+	
+	char *c = (char*)g_ptr_array_index(fifo->items, index);
+	char *s = g_strdup(c);
+	z_str_uc(s);
+
+	len = strlen(s);
+	for (i1 = x + fifo->ho; i1 >= 0 && i1 < len; i1--){
+		if (s[i1] >= 'A' && s[i1] <= 'Z') continue;
+		if (s[i1] >= '0' && s[i1] <= '9') continue;
+		if (s[i1] == '-') continue;
+		if (s[i1] == '/') continue;
+		break;
+	}
+	i1++; // line cannot begin with call
+
+	len = strlen(s);
+	for (i2 = x+fifo->ho; i2 < len; i2++){
+		if (s[i2] >= 'A' && s[i2] <= 'Z') continue;
+		if (s[i2] >= '0' && s[i2] <= '9') continue;
+		if (s[i2] == '-') continue;
+		if (s[i2] == '/') continue;
+		break;
+	}
+	if (i2 > i1 && i2 - i1 < 20){
+		g_strlcpy(call, s + i1, Z_MIN(i2 - i1 + 1, 20));
+		if (z_can_be_call(call, ZCBC_SLASH | ZCBC_MINUS)){
+			g_free(s);
+			return g_strdup(call);
+		}
+	}
+
+	return NULL;
+}
+
+void fifo_message(void *itdata, void *menudata){
+	int i;
+	if (!gses) return;
+
+	struct subwin *sw = sw_raise_or_new(SWT_KST);
+	sw_set_focus();
+	sw->callunder = g_strdup(gses->callunder);
+	sw_kst_message(itdata, sw);
+}
+
+
+
