@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2011 Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2011-2020 Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -35,5 +35,7 @@ int load_fifo_from_file(struct fifo *fifo, gchar *filename, int drop);
 void log_draw(struct fifo *fifo);
 void fifo_add_lines(struct fifo *fifo, char *data);
 int fifo_contains(struct fifo *fifo, char *needle);
+char *fifo_call_under(struct fifo *fifo, int x, int y);
+void fifo_message(void *itdata, void *menudata);
 
 #endif
