@@ -1,6 +1,6 @@
 /*
     kst - ON4KST chat
-    Copyright (C) 2011-2018 Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2011-2020 Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -975,16 +975,16 @@ void sw_kst_append_qrg(GString *gs){
 
     if (aband->skedqrg){
         if (strlen(aband->skedqrg) > 0){
-            g_string_sprintfa(gs, "%s ", aband->skedqrg);
+            g_string_append_printf(gs, "%s ", aband->skedqrg);
             if (aband->skedqrg[0] != '.') full_qrg = 1; // defined but no leading dot
         }
     }
     if (!full_qrg){ // not full qrg information
         if (aband->qrg_min < 20000000){
             struct config_band *confb = get_config_band_by_bandchar(aband->bandchar);
-            if (confb) g_string_sprintfa(gs, "on %s ", confb->adifband);
+            if (confb) g_string_append_printf(gs, "on %s ", confb->adifband);
         }else{
-            g_string_sprintfa(gs, "on %s ", aband->pband);
+            g_string_append_printf(gs, "on %s ", aband->pband);
         }
     }
 }
@@ -997,7 +997,7 @@ void sw_kst_ask_sked(void *itdata, void *menudata){
     GString *gs = g_string_sized_new(256);
 
     
-    g_string_sprintfa(gs, "/cq %s ", sw->callunder);
+    g_string_append_printf(gs, "/cq %s ", sw->callunder);
     
     if (itdata != NULL && GPOINTER_TO_INT(itdata) == 1){
         now = time(&now);
@@ -1008,7 +1008,7 @@ void sw_kst_ask_sked(void *itdata, void *menudata){
         else g_string_append(gs, "GE ");
 
         name = find_name_by_call(namedb, sw->callunder);
-        if (name) g_string_sprintfa(gs, "%s, ", name);
+        if (name) g_string_append_printf(gs, "%s, ", name);
 
         g_string_append(gs, "PSE sked ");
     }else{
@@ -1018,9 +1018,9 @@ void sw_kst_ask_sked(void *itdata, void *menudata){
     sw_kst_append_qrg(gs);
 
     if (itdata != NULL && GPOINTER_TO_INT(itdata) == 1)
-        g_string_sprintfa(gs, "OK?");
+        g_string_append_printf(gs, "OK?");
     else
-        g_string_sprintfa(gs, "and have ANT in your direction. Could you check it?");
+        g_string_append_printf(gs, "and have ANT in your direction. Could you check it?");
     
     askkst(sw->il, gs->str);
 
