@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2015  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2020  Ladislav Vaiz <ok1zia@nagano.cz>
     and authors of web browser Links 0.96
 
     This program is free software; you can redistribute it and/or
@@ -429,13 +429,13 @@ void trace_handler(char *s){
 }
 
 void info(GString *gs){
-    g_string_sprintfa(gs, "\n  %s-%s %s\n\n", PACKAGE, Z_PLATFORM, VERSION);
-    g_string_sprintfa(gs, "tucnak svn version: %s\nlibzia svn version: %s\n\n", T_SVNVER, z_svnver());
+    g_string_append_printf(gs, "\n  %s-%s %s\n\n", PACKAGE, Z_PLATFORM, VERSION);
+    g_string_append_printf(gs, "tucnak svn version: %s\nlibzia svn version: %s\n\n", T_SVNVER, z_svnver());
 #ifdef __GLIBC__
-    g_string_sprintfa(gs,"\n  glibc info\n");
-    g_string_sprintfa(gs,"compiled version: %d.%d\n", __GLIBC__, __GLIBC_MINOR__);
-    g_string_sprintfa(gs,"runtime version: %s\n", gnu_get_libc_version());
-    g_string_sprintfa(gs,"runtime release: %s\n\n", gnu_get_libc_release());
+    g_string_append_printf(gs,"\n  glibc info\n");
+    g_string_append_printf(gs,"compiled version: %d.%d\n", __GLIBC__, __GLIBC_MINOR__);
+    g_string_append_printf(gs,"runtime version: %s\n", gnu_get_libc_version());
+    g_string_append_printf(gs,"runtime release: %s\n\n", gnu_get_libc_release());
 #endif
 #ifdef Z_HAVE_SDL        
     sdl_info(gs);
@@ -463,21 +463,21 @@ void info(GString *gs){
     //SDL_ANDROID_GetHW(&h, &w, &state);
     zandroid_init(zsel);
     zandroid_get_location(&h, &w, &state);
-    g_string_sprintfa(gs, "\n  geolocation info\n");
-    g_string_sprintfa(gs, "state: ");
+    g_string_append_printf(gs, "\n  geolocation info\n");
+    g_string_append_printf(gs, "state: ");
     switch (state){
         case 0: g_string_append(gs, "searching\n"); break;
         case 1: g_string_append(gs, "fixed\n"); break;
         case 2: g_string_append(gs, "error\n"); break;
-        default: g_string_sprintfa(gs, "unknown\n", state); break;
+        default: g_string_append_printf(gs, "unknown\n", state); break;
     }
     if (h > -1000 && h < 1000){
-	    g_string_sprintfa(gs, "lon: %f\n", h);
-	    g_string_sprintfa(gs, "lat: %f\n", w);
+	    g_string_append_printf(gs, "lon: %f\n", h);
+	    g_string_append_printf(gs, "lat: %f\n", w);
         hw2loc(pwwlo, h, w, 10);
-		g_string_sprintfa(gs, "wwl: %s\n", pwwlo);
+		g_string_append_printf(gs, "wwl: %s\n", pwwlo);
 	}else{
-		g_string_sprintfa(gs, "location unknown\n");
+		g_string_append_printf(gs, "location unknown\n");
 	}
 #endif
     g_string_append(gs, "");
@@ -487,77 +487,77 @@ void settings(GString *gs){
 	z_get_settings(gs);
 	g_string_append(gs, "\n\n");
 	g_string_append(gs, txt_settings);
-    g_string_sprintfa(gs, "    macros: ");
+    g_string_append_printf(gs, "    macros: ");
 #ifdef UNIX
-    g_string_sprintfa(gs, "UNIX ");  
+    g_string_append_printf(gs, "UNIX ");  
 #endif
 #ifdef _UNIX
-    g_string_sprintfa(gs, "_UNIX ");  
+    g_string_append_printf(gs, "_UNIX ");  
 #endif
 #ifdef __UNIX
-    g_string_sprintfa(gs, "__UNIX ");  
+    g_string_append_printf(gs, "__UNIX ");  
 #endif
 #ifdef LINUX
-    g_string_sprintfa(gs, "LINUX ");
+    g_string_append_printf(gs, "LINUX ");
 #endif
 #ifdef _LINUX
-    g_string_sprintfa(gs, "_LINUX ");
+    g_string_append_printf(gs, "_LINUX ");
 #endif
 #ifdef __LINUX
-    g_string_sprintfa(gs, "__LINUX ");
+    g_string_append_printf(gs, "__LINUX ");
 #endif
 #ifdef WIN32
-    g_string_sprintfa(gs, "WIN32 ");
+    g_string_append_printf(gs, "WIN32 ");
 #endif
 #ifdef _WIN32
-    g_string_sprintfa(gs, "_WIN32 ");
+    g_string_append_printf(gs, "_WIN32 ");
 #endif
 #ifdef _WIN64
-    g_string_sprintfa(gs, "_WIN64 ");
+    g_string_append_printf(gs, "_WIN64 ");
 #endif
 #ifdef __CYGWIN__
-    g_string_sprintfa(gs, "__CYGWIN__ ");
+    g_string_append_printf(gs, "__CYGWIN__ ");
 #endif
 #ifdef __GNUC__
-    g_string_sprintfa(gs, "__GNUC__=%d.%d.%d ", __GNUC__, __GNUC_MINOR__, __GNUC_PATCHLEVEL__);
+    g_string_append_printf(gs, "__GNUC__=%d.%d.%d ", __GNUC__, __GNUC_MINOR__, __GNUC_PATCHLEVEL__);
 #endif
 #ifdef _MSC_VER
-    g_string_sprintfa(gs, "_MSC_VER=%d.%02d ", _MSC_VER / 100, _MSC_VER % 100);
+    g_string_append_printf(gs, "_MSC_VER=%d.%02d ", _MSC_VER / 100, _MSC_VER % 100);
 #endif
 #ifdef __MINGW32__
-    g_string_sprintfa(gs, "__MINGW32__ ");
+    g_string_append_printf(gs, "__MINGW32__ ");
 #endif
 #ifdef __x86_64__
-    g_string_sprintfa(gs, "__x86_64__ ");
+    g_string_append_printf(gs, "__x86_64__ ");
 #endif
 #ifdef __i386__
-    g_string_sprintfa(gs, "__i386__ ");
+    g_string_append_printf(gs, "__i386__ ");
 #endif
 #ifdef __hppa__
-    g_string_sprintfa(gs, "__hppa__ ");
+    g_string_append_printf(gs, "__hppa__ ");
 #endif
 #ifdef __ppc__
-    g_string_sprintfa(gs, "__ppc__ ");
+    g_string_append_printf(gs, "__ppc__ ");
 #endif
 #ifdef __powerpc__
-    g_string_sprintfa(gs, "__powerpc__ ");
+    g_string_append_printf(gs, "__powerpc__ ");
 #endif
 #ifdef __arm__
-    g_string_sprintfa(gs, "__arm__ ");
+    g_string_append_printf(gs, "__arm__ ");
 #endif
 #ifdef Z_UNIX
-    g_string_sprintfa(gs, "Z_UNIX ");
+    g_string_append_printf(gs, "Z_UNIX ");
 #endif
 #ifdef Z_MSC
-    g_string_sprintfa(gs, "Z_MSC ");
+    g_string_append_printf(gs, "Z_MSC ");
 #endif
 #ifdef Z_MINGW
-    g_string_sprintfa(gs, "Z_MINGW ");
+    g_string_append_printf(gs, "Z_MINGW ");
 #endif
 #ifdef Z_MINGW
-    g_string_sprintfa(gs, "Z_CYGWIN ");
+    g_string_append_printf(gs, "Z_CYGWIN ");
 #endif
-    g_string_sprintfa(gs, "\n");
+    g_string_append_printf(gs, "\n");
 }
 
 static void init(void)
@@ -735,16 +735,16 @@ static void init(void)
 	gs = g_string_new("");
 	ST_START();
 	for (i = 0; i < 10000; i++) {
-		g_string_sprintfa(gs, "%-14s %-6s %08d %s\n", "OK1ZIA", "JN69QR", 20120308, "C");
+		g_string_append_printf(gs, "%-14s %-6s %08d %s\n", "OK1ZIA", "JN69QR", 20120308, "C");
 	}
 	g_string_truncate(gs, 0);
-	ST_STOP("g_string_sprintfa");
+	ST_STOP("g_string_append_printf");
 
 	for (i = 0; i < 10000; i++) {
-		zg_string_sprintfa(gs, "%-14s %-6s %08d %s\n", "OK1ZIA", "JN69QR", 20120308, "C");
+		zg_string_append_printf(gs, "%-14s %-6s %08d %s\n", "OK1ZIA", "JN69QR", 20120308, "C");
 	}
 	g_string_truncate(gs, 0);
-	ST_STOP("zg_string_sprintfa");
+	ST_STOP("zg_string_append_printf");
 
 	for (i = 0; i < 10000; i++) {
 		char s[256], *c;
