@@ -12,12 +12,15 @@
 
 #include "ac.h"
 #include "bfu.h"
-#include "cor.h"
+#ifdef Z_HAVE_SDL
+#include "cordata.h"
+#endif
 #include "fifo.h"
 #include "html.h"
 #include "icons.h"
 #include "kbdbind.h"
 #include "kbd.h"
+#include "main.h"
 #include "map.h"
 #include "qrvdb.h"
 #include "rain.h"
@@ -111,6 +114,11 @@ int sw_map_kbd_func(struct subwin *sw, struct event *ev, int fw){
             sw->gdirty=1;
             redraw_later();
             break;
+		case 'w':
+			sw->showwwls = !sw->showwwls;
+            sw->gdirty=1;
+            redraw_later();
+            break;
     }
     return 0;
 }
@@ -131,6 +139,14 @@ void zoom(struct subwin *sw, double factor, int centerx, int centery){
 	sw->gdirty=1;
     redraw_later();
     dbg("zoom=%d\n", sw->zoom);
+
+	int size = 512;
+	double qrb, qtf, dh, dw;
+	px2km(sw, size, size, &kx, &kx);
+	km2qrbqtf(kx, ky, &qrb, &qtf);
+	qrbqtf2hw(sw->myh, sw->myw, qrb, qtf, &dh, &dw);
+
+	/*int gz =*/ tile_googlezoom(size, dh, dw, size, size);
 }
 
 int sw_map_mouse_func(struct subwin *sw, struct event *ev, int fw){
@@ -305,6 +321,7 @@ void sw_map_redraw_rect(struct subwin *sw, SDL_Rect *area, struct band *band, in
     /*SDL_FillRect(sw->screen, &sw->map, sdl->termcol[1]);
     SDL_FillRect(sw->screen, &sw->info, sdl->termcol[2]);*/
     
+	if (sw->showwwls) plot_wkd_wwls(sw, sw->l1map, area);
     plot_cor(sw, sw->l1map, area, flags);
 	//plot_qth(sw, area);
 //        dumpbitmap(sw->l1map);
@@ -381,12 +398,17 @@ void sw_map_redraw_rain(struct subwin *sw, SDL_Rect *aarea, int flags){
 	if (grain == NULL) return;
 	if ((flags & HTML_FOR_PHOTO) != 0) return;
 
+	/*{
+		SDL_BlitSurface(grain->weatheronline->img, NULL, sw->screen, &sw->map);
+        return;
+	}*/ 
 	for (ci = 0; ci < RAIN_COLORS; ci++){
+		if (grain->weatheronline != NULL) plot_rain_provider(sw, aarea, grain->weatheronline, ci);
 		if (grain->wetteronline != NULL) plot_rain_provider(sw, aarea, grain->wetteronline, ci);
 		if (grain->meteox != NULL) plot_rain_provider(sw, aarea, grain->meteox, ci);
 		if (grain->chmi != NULL) plot_rain_provider(sw, aarea, grain->chmi, ci);
 		if (grain->debug) break; 
-	}
+	} 
 }
 
 void plot_rain_provider(struct subwin *sw, SDL_Rect *aarea, struct rain_provider *provider, int ci)
@@ -417,8 +439,9 @@ void plot_rain_provider(struct subwin *sw, SDL_Rect *aarea, struct rain_provider
 		for (iy = 0; iy < provider->img->h; iy++){
 			for (ix = 0; ix < provider->img->w; ix++){
 				c = z_getpixel_fmt(provider->img, ix, iy, sdl->screen->format);
-				hh1 = provider->h1 + (ix - provider->hpx1) * provider->hmult;
-				ww1 = provider->w1 + (iy - provider->wpx1) * provider->wmult;
+				
+				provider->img2hw(provider, ix, iy, &hh1, &ww1);
+
 				hw2km(sw->myh, sw->myw, hh1, ww1, &kx, &ky);
 				km2px(sw, kx, ky, &px1, &py1);
         
@@ -535,6 +558,7 @@ void plot_rain_titles(SDL_Surface *surface, SDL_Rect *area, int flags){
     plot_rain_title(surface, area, flags, grain->chmi, &y);
     plot_rain_title(surface, area, flags, grain->wetteronline, &y);
     plot_rain_title(surface, area, flags, grain->meteox, &y);
+    plot_rain_title(surface, area, flags, grain->weatheronline, &y);
 }
 
 void sw_map_redraw(struct subwin *sw, struct band *band, int flags){
@@ -625,57 +649,7 @@ void pxkm2o(struct subwin *sw, int px, int py, int kx, int ky, int *ox, int *oy)
 }
 
 
-void hw2km(double h1, double w1, double h2, double w2, int *kx, int *ky){
-	double qrb, qtf;
-    
-	hw2qrbqtf(h1, w1, h2, w2, &qrb, &qtf);
-/*    dbg("qrb=%f qtf=%f\n", qrb, qtf);*/
-    *kx = (int)(  qrb*sin(qtf));
-    *ky = (int)(- qrb*cos(qtf));
-}
 
-#endif
-
-void hw2km_d(double h1, double w1, double h2, double w2, double *kx, double *ky){
-	double qrb, qtf;
-    
-	hw2qrbqtf(h1, w1, h2, w2, &qrb, &qtf);
-/*    dbg("qrb=%f qtf=%f\n", qrb, qtf);*/
-
-    *kx =   qrb*sin(qtf);
-    *ky = - qrb*cos(qtf);
-}
-
-void hw2km_f(double h1, double w1, double h2, double w2, float *fkx, float *fky){
-	double kx, ky;
-	hw2km_d(h1, w1, h2, w2, &kx, &ky);
-
-	/*if (ikx < -32768) ikx = -32768;
-	if (ikx > 32767) ikx = 32767;
-	if (iky < -32768) iky = -32768;
-	if (iky > 32767) iky = 32767;*/
-
-	*fkx = kx;
-	*fky = ky;
-}
-
-void km2qrbqtf(int kx, int ky, double *qrb, double *qtf){
-    int dx, dy;
-    
-    dx=kx;
-    dy=ky;
-    
-	if (qrb){
-		*qrb=sqrt((double)(sqr(dx)+sqr(dy)));
-	}
-	if (qtf){
-		*qtf=atan2((double)dx,(double)-dy);   
-		if (*qtf<0) *qtf+=2*M_PI;
-	}
-/*    dbg("km2qrbqtf(%d, %d)=%d, %d\n",kx, ky, (int)*qrb, (int)(*qtf*180.0/M_PI));*/
-}
-
-#ifdef Z_HAVE_SDL
 
 static int dashcnt;
 static void dashfce(SDL_Surface *surface, int x, int y, int d) {
@@ -831,6 +805,49 @@ void plot_cor(struct subwin *sw, SDL_Surface *surface, SDL_Rect *area, int flags
 //    zsdl_test_bars(surface, 0);
 }
 
+
+void plot_wkd_func(gpointer key, gpointer value, gpointer user_data){
+	GPtrArray *arr = (GPtrArray *)user_data;
+	g_ptr_array_add(arr, key);
+}
+
+void plot_wkd_wwls(struct subwin *sw, SDL_Surface *surface, SDL_Rect *area){
+
+	int i;
+	GPtrArray *arr;
+	int c = z_makecol(140, 0, 0);
+
+	if (!aband) return;
+	
+	arr = g_ptr_array_new();
+	g_hash_table_foreach(aband->stats->wwls, plot_wkd_func, arr);
+	
+	for (i = 0; i < arr->len; i++){
+		double h0, w0, h, w;
+		int kx, ky, j;
+		//SDL_Rect r;
+		int px[6], py[6];
+		char *wwl = (char*)g_ptr_array_index(arr, i);
+
+		h0 = qth(wwl, 0);
+		w0 = qth(wwl, 1);
+
+		for (j = 0; j < 6; j++){
+			h = h0 + (j / 2) * M_PI/180.0;
+			w = w0 + (j % 2) * M_PI/180.0;
+			
+			hw2km(gses->myh, gses->myw, h, w, &kx, &ky);
+			km2px(sw, kx, ky, &px[j], &py[j]);
+		}
+
+		z_triangle_net(surface, c, 6, px[0], py[0], px[1], py[1], px[2], py[2], px[3], py[3], px[4], py[4], px[5], py[5]);
+	}
+
+	
+	g_ptr_array_free(arr, TRUE);
+
+}
+
 void plot_qth(struct subwin *sw, SDL_Rect *area){
 	int px, py;
 	SDL_Rect r;
@@ -1077,7 +1094,7 @@ int map_update_qth(struct subwin *sw){
 	sw->myw = qth(sw->pwwlo, 1);
  //   dbg("   %s=%d %d\n", sw->pwwlo, sw->myh, sw->myw);
     
-    cor_recalc(sw, sw->pwwlo);
+    zcors_recalc(sw->myh, sw->myw, sw->pwwlo, zsel, map_cor_callback, cor_tucnakcor, COR_ITEMS);
 
 	acs_update_qth(gacs, sw);
 
@@ -1118,6 +1135,22 @@ int maps_reload(){
     return 0;
 }
 
+
+int maps_update_showwwls(){
+    int i;
+    struct subwin *sw;
+    
+    if (!sdl) return 0;
+    
+    for (i=0;i<gses->subwins->len;i++){
+        sw=(struct subwin *)g_ptr_array_index(gses->subwins, i);
+        if (sw->type!=SWT_MAP && sw->type != SWT_KST) continue;
+		sw->showwwls = ctest != NULL && ctest->wwlmult > 0;
+        sw->gdirty=1;
+    }
+	return 0;
+}
+
 void map_clear_qso(struct qso *qso, struct band *band){
     int kx, ky, px, py;
     SDL_Rect outline;
@@ -1152,8 +1185,8 @@ void map_recalc_cors(){
     for (i=0;i<gses->subwins->len;i++){
         sw=(struct subwin *)g_ptr_array_index(gses->subwins, i);
         if (sw->type!=SWT_MAP) continue;
-        cor_recalc(sw, ctest->pwwlo);
-        break; /* fixme more maps with different pwwlo. but why? */
+        zcors_recalc(sw->myh, sw->myw, ctest->pwwlo, zsel, map_cor_callback, cor_tucnakcor, COR_ITEMS);
+        break; /* more maps with different pwwlo. but why? */
     }
 } 
 
@@ -1348,7 +1381,8 @@ int plot_qrb_qth(struct subwin *sw, SDL_Surface *surface, int mouse_x, int mouse
     SDL_Rect rect;
     char buf[100];
     int x, y, kx, ky;
- 
+ 	char *sss;
+
     x=sw->info.x+4;
     y=sw->info.y+(11*FONT_H)+12;
     
@@ -1367,20 +1401,38 @@ int plot_qrb_qth(struct subwin *sw, SDL_Surface *surface, int mouse_x, int mouse
     if (mouse_x < 0) return 0;
 
 
-    zsdl_printf(surface, x, y, sdl->green, 0, ZFONT_TRANSP, VTEXT(T_GQRB), (int)(qrb));y+=FONT_H+4;
+    sss = VTEXT(T_GQRB);
+    
+    //dbg("plot_qtb_qtf sss='%s'\n", sss);
+    zsdl_printf(surface, x, y, sdl->green, 0, ZFONT_TRANSP, sss, (int)(qrb));
+    y+=FONT_H+4;
     zsdl_printf(surface, x, y, sdl->green, 0, ZFONT_TRANSP, VTEXT(T_GQTF), (int)(qtf*180/M_PI)); y+=FONT_H+4;
    /* fontoutf(surface, x, y, sdl->green, FONT_TRANSP, VTEXT(T_GINC), (int) (gst[(int)(qtf*180/M_PI)%360]/400*100));y+=FONT_H+4; */
-#if 1
+#if -1
     if (qrbqtf2hw(sw->myh, sw->myw, qrb, qtf, &h2, &w2)==0){
         zsdl_printf(surface, x, y, sdl->green, 0, ZFONT_TRANSP, VTEXT(T_GLON), h2*180.0/M_PI, x2gramin(buf, sizeof(buf), h2*180/M_PI, "EW")); y+=FONT_H+4;
         zsdl_printf(surface, x, y, sdl->green, 0, ZFONT_TRANSP, VTEXT(T_GLAT), w2*180.0/M_PI, x2gramin(buf, sizeof(buf), w2*180/M_PI, "NS")); y+=FONT_H+4;
         zsdl_printf(surface, x, y, sdl->green, 0, ZFONT_TRANSP, VTEXT(T_GLOC), hw2loc(buf, h2*180/M_PI, w2*180/M_PI, 6)); y+=FONT_H+4;
     }
 #else    
-	zsdl_printf(surface, x, y, sdl->gr[15], 0, ZFONT_TRANSP, "mouse %d %d", mouse_x, mouse_y); y += FONT_H;
-	zsdl_printf(surface, x, y, sdl->gr[15], 0, ZFONT_TRANSP, "k     %d %d", kx, ky); y += FONT_H;
-	zsdl_printf(surface, x, y, sdl->gr[15], 0, ZFONT_TRANSP, "o     %d %d", sw->ox, sw->oy); y += FONT_H;
-	zsdl_printf(surface, x, y, sdl->gr[15], 0, ZFONT_TRANSP, "z     %d", sw->zoom); y += FONT_H;
+	{
+		int mx = mouse_x - sw->x*FONT_W;
+		int my = mouse_y - sw->y*FONT_H;
+
+        double dx = mx - 234;
+        double dy = my + 280;
+        double d = sqrt(dx * dx + dy * dy) / 12.6 - 5;
+        double a = atan2(dy, dx);
+        double w = 90 - d;
+        double h = 90 - (a * 180 / M_PI) + 12;
+        h *= 27.5 / 22.0;
+
+		zsdl_printf(surface, x, y, sdl->gr[15], 0, ZFONT_TRANSP, "mxy %d %d", mx, my); y += FONT_H;
+	    zsdl_printf(surface, x, y, sdl->gr[15], 0, ZFONT_TRANSP, "dxy %4.2f %4.2f", dx, dy); y += FONT_H;
+		zsdl_printf(surface, x, y, sdl->gr[15], 0, ZFONT_TRANSP, "da %4.2f %4.2f", d, a * 180 / M_PI); y += FONT_H;
+		zsdl_printf(surface, x, y, sdl->gr[15], 0, ZFONT_TRANSP, "hw %4.2f %4.2f", h, w); y += FONT_H;
+		//zsdl_printf(surface, x, y, sdl->gr[15], 0, ZFONT_TRANSP, "z     %d", sw->zoom); y += FONT_H;
+	}
 #endif
     return 0;
 }
@@ -1558,6 +1610,14 @@ void plot_hgts(struct subwin *sw, SDL_Rect *area){
 	plot_hgt(sw, area, 600, 600, "N49E013.hgt");
 }
 
+void map_cor_callback(void)
+{
+	if (!gses) return;
+    if (gses->ontop->type!=SWT_MAP) return;
+    gses->ontop->gdirty = 1;
+    sw_map_redraw(gses->ontop, aband, 0);
+}
+
 #else
 int sw_map_kbd_func(struct subwin *sw, struct event *ev, int fw){
     return 0;
@@ -1585,4 +1645,6 @@ void map_clear_qso(struct qso *qso, struct band *band){
 
 void map_add_qso(struct qso *qso, struct band *band){
 }
+int maps_update_showwwls(){
+}
 #endif
