@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2015  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2020  Ladislav Vaiz <ok1zia@nagano.cz>
     and authors of web browser Links 0.96
 
     This program is free software; you can redistribute it and/or
@@ -1326,7 +1326,7 @@ void menu_load_from_peer(void *arg){
             if (!conn_prod_state(conn)) continue;
             op="---";
             if (ctest && aband && conn->operator_) op=conn->operator_;
-            g_string_sprintfa(gs,"%s;%s;", conn->remote_id, op);
+            g_string_append_printf(gs,"%s;%s;", conn->remote_id, op);
         }
         gnet->allpeers=g_strdup(gs->str);
         g_string_free(gs,TRUE);
@@ -1370,7 +1370,7 @@ void do_spy_peer_menu(void (* func)(void *arg)){
             add_to_menu(&mi,g_strdup(c),"", "", MENU_FUNC func, GINT_TO_POINTER(menui), 0);
 			dbg("add_to_menu(%s) menui=%d\n", c, menui);
             g_free(c);
-            g_string_sprintfa(gs, "%s;%s;%c;", items[i], items[i+1], *d);
+            g_string_append_printf(gs, "%s;%s;%c;", items[i], items[i+1], *d);
 			menui++;
         }
     }
@@ -1411,7 +1411,7 @@ void menu_spy_from_peer(void *arg){
             if (ctest && aband && conn->operator_) op=conn->operator_;
             rwb="";
             if (conn->rwbands) rwb=conn->rwbands;
-            g_string_sprintfa(gs,"%s;%s;%s;", conn->remote_id, op, rwb);
+            g_string_append_printf(gs,"%s;%s;%s;", conn->remote_id, op, rwb);
         }
         gnet->rwbpeers=g_strdup(gs->str);
         g_string_free(gs,TRUE);
@@ -1573,7 +1573,7 @@ void menu_contest_config_from_peer(void *arg){
             pcall = ztokenize(zs, 0);
             tname = ztokenize(zs, 0);
             if (tname && *tname)
-                g_string_sprintfa(gs,"%s;%s %s %s;", tmpconn->remote_id, cdate, pcall, tname);
+                g_string_append_printf(gs,"%s;%s %s %s;", tmpconn->remote_id, cdate, pcall, tname);
             zfree(zs);
         }
         dbg("allpeers=%s\n", gs->str);
