@@ -59,16 +59,16 @@ int dlg_mode(struct dialog_data *dlg, struct dialog_item_data *di){
 
 /******************** EDIT QSO *******************************/
 
-char callsign[EQSO_LEN], rstr[EQSO_LEN], qsonrr[EQSO_LEN], exc[EQSO_LEN], locator[EQSO_LEN];
+static char callsign[EQSO_LEN], rstr[EQSO_LEN], qsonrr[EQSO_LEN], exc[MAX_EXC_LEN+1], locator[EQSO_LEN];
 /*gint mode;
 char mode_str[EQSO_LEN]*/
 char rsts[EQSO_LEN], qsonrs[EQSO_LEN];
-char date_str[EQSO_LEN], time_str[EQSO_LEN], operator_[EQSO_LEN], remark[MAX_STR_LEN]; 
+static char date_str[EQSO_LEN], time_str[EQSO_LEN], operator_[EQSO_LEN], remark[MAX_STR_LEN]; 
 gint qerror,qsl;
 
 #define OEQSO_LEN 24
 #define QRG_LEN 50
-char ocallsign[OEQSO_LEN], orstr[OEQSO_LEN], oqsonrr[OEQSO_LEN], oexc[OEQSO_LEN], olocator[OEQSO_LEN];
+char ocallsign[OEQSO_LEN], orstr[OEQSO_LEN], oqsonrr[OEQSO_LEN], oexc[MAX_EXC_LEN+1], olocator[OEQSO_LEN];
 char omode_str[OEQSO_LEN], orsts[OEQSO_LEN], oqsonrs[OEQSO_LEN];
 char odate_str[OEQSO_LEN], otime_str[OEQSO_LEN], ooperator[OEQSO_LEN], oremark[MAX_STR_LEN], oqrg[QRG_LEN]; 
 
@@ -283,7 +283,7 @@ void edit_qso(struct qso *qso)
     struct dialog *d;
     int i, len;
     static char ss[102];
-    char s[100];
+    char s[1000];
     
 
 /*    dbg("edit_qso\n");*/
@@ -294,7 +294,7 @@ void edit_qso(struct qso *qso)
     safe_strncpy0(callsign,  qso->callsign,  EQSO_LEN); z_str_uc(callsign);
     safe_strncpy0(rstr,      qso->rstr,      EQSO_LEN);
     safe_strncpy0(qsonrr,    qso->qsonrr,    EQSO_LEN);
-    safe_strncpy0(exc,       qso->exc,       EQSO_LEN); 
+    safe_strncpy0(exc,       qso->exc,       MAX_EXC_LEN+1); 
     safe_strncpy0(locator,   qso->locator,   EQSO_LEN); z_str_uc(locator);
     mode=qso->mode;
     safe_strncpy0(mode_str,  get_text_translation(mode_msg[mode]), EQSO_LEN);
@@ -360,7 +360,8 @@ void edit_qso(struct qso *qso)
     d->items[i].data = qsonrr;
     
     d->items[++i].type = D_FIELD;
-    d->items[i].dlen = EQSO_LEN;
+	d->items[i].dlen = MAX_EXC_LEN + 1;
+	d->items[i].maxl = EQSO_LEN;
     d->items[i].data = exc;
     
     d->items[++i].type = D_FIELD;
