@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2015  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2020  Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -1020,29 +1020,29 @@ void do_unfinished(struct session *ses, char *remark){
             gchar *c;
             remark[17]='\0';
             c = g_strdup_printf("%s %s", remark, TMPQ.callsign);
-            g_string_sprintfa(gs, "%-24s", c);
+            g_string_append_printf(gs, "%-24s", c);
             g_free(c);
         }else{
-            g_string_sprintfa(gs, "%-10s %-13s", remark, TMPQ.callsign); 
+            g_string_append_printf(gs, "%-10s %-13s", remark, TMPQ.callsign); 
         }
     }else{
         remark[24]='\0';
-        g_string_sprintfa(gs, "%-24s",remark);
+        g_string_append_printf(gs, "%-24s",remark);
     }
 
             
-    g_string_sprintfa(gs, "%5s%4s %5s%4s",
+    g_string_append_printf(gs, "%5s%4s %5s%4s",
         TMPQ.rsts?TMPQ.rsts:"---", 
         TMPQ.qsonrs?TMPQ.qsonrs: "---",
         TMPQ.rstr?TMPQ.rstr:"---", 
         TMPQ.qsonrr?TMPQ.qsonrr:"---");
 
     if (TMPQ.locator && TMPQ.ulocator){
-        g_string_sprintfa(gs, "    %-8s %7d %3d", TMPQ.locator, (int)TMPQ.qrb, TMPQ.qtf);
+        g_string_append_printf(gs, "    %-8s %7d %3d", TMPQ.locator, (int)TMPQ.qrb, TMPQ.qtf);
     }
 #ifdef HAVE_HAMLIB
 	if (gtrigs->trigs->len > 0){
-        g_string_sprintfa(gs, "  %1.1f", gtrigs->qrg/1000.0);
+        g_string_append_printf(gs, "  %1.1f", gtrigs->qrg/1000.0);
     }
 #endif
 
