@@ -392,6 +392,7 @@ char weight_str[EQSO_LEN];
 char minwpm_str[EQSO_LEN], maxwpm_str[EQSO_LEN];
 int cwda_spk;
 char leadin_str[EQSO_LEN];
+char tail_str[EQSO_LEN];
 char autgive_str[EQSO_LEN];
     
 void refresh_cwda(void *xxx){
@@ -408,6 +409,7 @@ void refresh_cwda(void *xxx){
     cfg->cwda_maxwpm = atoi(maxwpm_str);
     cfg->cwda_spk = cwda_spk;
     cfg->cwda_leadin = atoi(leadin_str);
+    cfg->cwda_tail = atoi(tail_str);
     cfg->cwda_autgive = atoi(autgive_str);
 	
 	free_cwdaemon(cwda);
@@ -432,6 +434,7 @@ void menu_cwda(void *arg){
     g_snprintf(maxwpm_str, EQSO_LEN, "%d", cfg->cwda_maxwpm);
     cwda_spk=cfg->cwda_spk;
     g_snprintf(leadin_str, EQSO_LEN, "%d", cfg->cwda_leadin);
+    g_snprintf(tail_str, EQSO_LEN, "%d", cfg->cwda_tail);
     g_snprintf(autgive_str, EQSO_LEN, "%d", cfg->cwda_autgive);
 
     
@@ -465,14 +468,21 @@ void menu_cwda(void *arg){
     d->items[i].data = (char *)&cwda_type;
     d->items[i].msg = CTEXT(T_TTYS);
 	
-    d->items[++i].type = D_CHECKBOX;
+	d->items[++i].type = D_CHECKBOX;
+	d->items[i].gid = 1;
+	d->items[i].gnum = CWD_TTYS_SINGLE;
+	d->items[i].dlen = sizeof(int);
+	d->items[i].data = (char *)&cwda_type;
+	d->items[i].msg = CTEXT(T_TTYSSINGLE);
+	d->items[i].wrap = 1;
+
+	d->items[++i].type = D_CHECKBOX;
     d->items[i].gid = 1;
     d->items[i].gnum = CWD_DAVAC4;
     d->items[i].dlen = sizeof(int);
     d->items[i].data = (char *)&cwda_type;
     d->items[i].msg = "Davac4";
-    d->items[i].wrap = 1;
-	
+    
     d->items[++i].type = D_CHECKBOX;
     d->items[i].gid = 1;
     d->items[i].gnum = CWD_CWD;
@@ -493,9 +503,9 @@ void menu_cwda(void *arg){
     d->items[i].dlen = sizeof(int);
     d->items[i].data = (char *)&cwda_type;
     d->items[i].msg = "winkey TCP";
-    d->items[i].wrap = 1;
-	
-    d->items[++i].type = D_FIELD;       
+	d->items[i].wrap = 1;
+
+	d->items[++i].type = D_FIELD;
     d->items[i].dlen = MAX_STR_LEN;
     d->items[i].data = cwda_device;
     d->items[i].maxl = 20;
@@ -571,6 +581,15 @@ void menu_cwda(void *arg){
     d->items[i].gid  = 0;
     d->items[i].gnum = 10000;
     d->items[i].msg = CTEXT(T_LEADIN);
+
+	d->items[++i].type = D_FIELD;  
+    d->items[i].dlen = EQSO_LEN;
+    d->items[i].data = tail_str;
+    d->items[i].maxl = 6;
+    d->items[i].fn   = check_number;
+    d->items[i].gid  = 0;
+    d->items[i].gnum = 10000;
+    d->items[i].msg = TRANSLATE("PTT tail [ms]");//CTEXT(T_LEADIN);
     d->items[i].wrap = 1;
 
     d->items[++i].type = D_FIELD;     /* 15 */
@@ -987,17 +1006,19 @@ void do_ssbd(void){
 #ifdef HAVE_PORTAUDIO
 	if (cfg->ssbd_pa_play < 0) cfg->ssbd_pa_play = Pa_GetDefaultOutputDevice();
     di = Pa_GetDeviceInfo(cfg->ssbd_pa_play);
-    if (di)
-        safe_strncpy(ssbd_pa_play_src, di->name, MAX_STR_LEN);
-    else
-        safe_strncpy0(ssbd_pa_play_src, VTEXT(T_RECSRC_NONE), MAX_STR_LEN);
+	if (di){
+		safe_strncpy(ssbd_pa_play_src, di->name, MAX_STR_LEN);
+	}else{
+		safe_strncpy0(ssbd_pa_play_src, VTEXT(T_RECSRC_NONE), MAX_STR_LEN);
+	}
     
 	if (cfg->ssbd_pa_rec < 0) cfg->ssbd_pa_rec = Pa_GetDefaultInputDevice();
     di = Pa_GetDeviceInfo(cfg->ssbd_pa_rec);
-    if (di)
-        safe_strncpy(ssbd_pa_rec_src, di->name, MAX_STR_LEN);
-    else
-        safe_strncpy0(ssbd_pa_rec_src, VTEXT(T_RECSRC_NONE), MAX_STR_LEN);
+	if (di){
+		safe_strncpy(ssbd_pa_rec_src, di->name, MAX_STR_LEN);
+	}else{
+		safe_strncpy0(ssbd_pa_rec_src, VTEXT(T_RECSRC_NONE), MAX_STR_LEN);
+	}
 #endif
     
 
