@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2012-2016 Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2012-2018 Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -25,12 +25,13 @@
 #include "tsdl.h"
 
 int httpd_enable, httpd_show_priv;
-char httpd_port_str[EQSO_LEN];
+char httpd_port_str[EQSO_LEN], httpd_refresh_str[EQSO_LEN];
 
 void refresh_httpd_opts(void *arg){
     cfg->httpd_enable = httpd_enable;
     STORE_SINT(cfg, httpd_port);
     cfg->httpd_show_priv = httpd_show_priv;
+    STORE_SINT(cfg, httpd_refresh);
 
 	free_httpd(httpd);
 	httpd = init_httpd();
@@ -44,6 +45,7 @@ void menu_httpd_opts(void *arg){
     httpd_enable = cfg->httpd_enable;
     g_snprintf(httpd_port_str, EQSO_LEN, "%d", cfg->httpd_port);
     httpd_show_priv = cfg->httpd_show_priv;
+    g_snprintf(httpd_refresh_str, EQSO_LEN, "%d", cfg->httpd_refresh);
 
     d = (struct dialog *)g_malloc(sizeof(struct dialog) + 20 * sizeof(struct dialog_item));
     memset(d, 0, sizeof(struct dialog) + 20 * sizeof(struct dialog_item));
@@ -76,8 +78,18 @@ void menu_httpd_opts(void *arg){
     d->items[i].dlen = sizeof(int);
     d->items[i].data = (char *)&httpd_show_priv;
     d->items[i].msg = CTEXT(T_PRIVATE);//CTEXT(T_RIG_QRG_R2T);
-    d->items[i].wrap = 2;
+    d->items[i].wrap = 1;
     
+    d->items[++i].type = D_FIELD;
+    d->items[i].dlen = EQSO_LEN;
+    d->items[i].data = httpd_refresh_str;
+    d->items[i].maxl = 7;
+    d->items[i].fn   = check_number;
+    d->items[i].gid  = 0;
+    d->items[i].gnum  = 999;
+    d->items[i].msg  = CTEXT(T_REFRESH);//CTEXT(T_RIG_MODEL);
+    d->items[i].wrap = 2;
+
     d->items[++i].type = D_BUTTON;   /* 6 */
     d->items[i].gid = B_ENTER;
     d->items[i].fn = ok_dialog;
@@ -324,6 +336,7 @@ char ac_maxelev_str[DBL_LEN];
 char ac_mindur_str[DBL_LEN];       
 char ac_maxdelta_str[DBL_LEN];  
 char ac_minalt_str[DBL_LEN];
+char kst_maxqrb_str[MAX_STR_LEN];
 
 void refresh_ac_opts(void *arg){
     STORE_INT(cfg, ac_enable);
@@ -335,6 +348,7 @@ void refresh_ac_opts(void *arg){
     STORE_SINT(cfg, ac_mindur);
     STORE_SDBL(cfg, ac_maxdelta);
     STORE_SINT(cfg, ac_minalt);
+	STORE_SINT(cfg, kst_maxqrb);
 
 
 	free_acs(gacs);
@@ -355,6 +369,7 @@ void menu_ac_opts(void *arg){
     g_snprintf(ac_mindur_str,  DBL_LEN, "%d", cfg->ac_mindur);
     g_snprintf(ac_maxdelta_str, DBL_LEN, "%3.1f", cfg->ac_maxdelta);
     g_snprintf(ac_minalt_str, DBL_LEN, "%d", cfg->ac_minalt);
+	LOAD_SINT(cfg, kst_maxqrb);
 
 
     d = (struct dialog *)g_malloc(sizeof(struct dialog) + 20 * sizeof(struct dialog_item));
@@ -425,7 +440,16 @@ void menu_ac_opts(void *arg){
     d->items[i].gid  = 0;
     d->items[i].gnum = 20000;
     d->items[i].msg = TRANSLATE("Minimal AC altitude [m]");
-    d->items[i].wrap = 2;
+    d->items[i].wrap = 1;
+
+	d->items[++i].type = D_FIELD;
+	d->items[i].dlen = MAX_STR_LEN;
+	d->items[i].data = (char*)&kst_maxqrb_str;
+	d->items[i].maxl = 6;
+	d->items[i].msg = TRANSLATE("Maximal QRB for KST");// CTEXT(T_KST_MAXQRB);
+	d->items[i].wrap = 2;
+
+
 
     
     d->items[++i].type = D_BUTTON;
@@ -561,12 +585,12 @@ static int dlg_sdr_af_filename(struct dialog_data *dlg, struct dialog_item_data
 void sdr_opts_fn(struct dialog_data *dlg)
 {
 	if (strlen(new_sdr_sndfilename)>0 && sdr_sndfilename_index >= 0){
-        safe_strncpy0(dlg->items[sdr_sndfilename_index].cdata, new_sdr_sndfilename, MAX_STR_LEN);
+        g_strlcpy(dlg->items[sdr_sndfilename_index].cdata, new_sdr_sndfilename, MAX_STR_LEN);
 		dlg->items[sdr_sndfilename_index].cpos = strlen(new_sdr_sndfilename);
         strcpy(new_sdr_sndfilename, "");
     }
 	if (strlen(new_sdr_af_filename)>0 && sdr_af_filename_index >= 0){
-        safe_strncpy0(dlg->items[sdr_af_filename_index].cdata, new_sdr_af_filename, MAX_STR_LEN);
+        g_strlcpy(dlg->items[sdr_af_filename_index].cdata, new_sdr_af_filename, MAX_STR_LEN);
 		dlg->items[sdr_af_filename_index].cpos = strlen(new_sdr_af_filename);
         strcpy(new_sdr_af_filename, "");
     }
@@ -601,7 +625,7 @@ void refresh_sdr_opts(void *arg){
 #endif
 	STORE_STR(cfg, sdr_remoterx);
 
-#ifdef USE_SDR
+#if defined(USE_SDR) && defined(Z_HAVE_SDL)
     if (sdl){
         free_sdr(gsdr);
         gsdr = init_sdr();
@@ -764,6 +788,15 @@ void menu_sdr_opts(void *arg){
     d->items[i].msg = CTEXT(T_WAV_FILE);
 #endif
 
+#ifdef HAVE_LIBRTLSDR
+	d->items[++i].type = D_CHECKBOX;
+	d->items[i].gid = 1;
+	d->items[i].gnum = DSPT_RTLSDR;
+	d->items[i].dlen = sizeof(int);
+	d->items[i].data = (char *)&sdr_rec_dsp_type;
+	d->items[i].msg = TRANSLATE("RTL-SDR");//CTEXT(T_WAV_FILE);
+#endif
+
 	d->items[++i].type = D_CHECKBOX;
     d->items[i].gid = 1;
 	d->items[i].gnum = DSPT_SDRC;
@@ -776,10 +809,10 @@ void menu_sdr_opts(void *arg){
     d->items[++i].type = D_FIELD;
     d->items[i].dlen = EQSO_LEN;
     d->items[i].data = sdr_speed_str;
-    d->items[i].maxl = 7;
+    d->items[i].maxl = 9;
     d->items[i].fn   = check_number;
     d->items[i].gid  = 8000;
-    d->items[i].gnum = 192000;
+    d->items[i].gnum = 3200000;
     d->items[i].msg = CTEXT(T_SAMPLERATE); 
 	d->items[i].wrap = 1;
 	sdr_samplerate_index = i;
