@@ -62,6 +62,7 @@
 #define HAVE_HAMLIB
 //#define HAVE_LIBFTDI
 //#define HAVE_FTDI_NEW
+#define HAVE_LIBRTLSDR
 #define HAVE_SHLOBJ_H
 #define PKG "nsis"
 #define DDIR ""
@@ -74,11 +75,10 @@
 #define strcasecmp _stricmp
 #define strncasecmp _strnicmp
 #define getpid _getpid
-#define __attribute__(attr)
 
 typedef int pid_t;
 typedef int speed_t;
-typedef int iconv_t;
+//typedef int iconv_t;
 
 int main(int argc, char *argv[]);
 int CALLBACK WinMain(HINSTANCE hInstance, HINSTANCE hPrevInstance, LPSTR lpCmdLine, int nCmdShow);
