@@ -6,6 +6,8 @@
     modify it under the terms of the GNU General Public License
     version 2 as published by the Free Software Foundation.
 
+    UTF-8 detect: ěščřžýáíé
+
 */
 
 #include "header.h"
@@ -1054,7 +1056,7 @@ void sw_qrv_draw_qrv(struct subwin *sw, int i, struct qrv_item *qi, int color){
     char acint[30];
 
 #if defined(Z_HAVE_SDL) && !defined(Z_ANDROID)     
-    //if (sdl) degree='';
+    //if (sdl) degree='°';
     if (sdl) degree=0xb0;
 #endif
 
