@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2015  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2020  Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -926,10 +926,10 @@ void foreach_add_latests_str(gpointer key, gpointer value, gpointer data){
     if (strcmp((const char *)key,"neterr")==0) return;
     q = (struct qso *) z_ptr_array_index(ia, ia->len - 1);
     if (q){
-        g_string_sprintfa(gs, "%s;%d;", (char *)key, (int)q->stamp);
+        g_string_append_printf(gs, "%s;%d;", (char *)key, (int)q->stamp);
     }else{ /* not reached, NULL can be only in the middle of iarray */
         dbg("ERROR! q is NULL (foreach_add_latests_str)\n");
-        g_string_sprintfa(gs, "%s;NULL;", (char *)key);
+        g_string_append_printf(gs, "%s;NULL;", (char *)key);
     }
 }
 
