@@ -25,7 +25,7 @@
 #include "zstring.h"
 
 struct rotar *rota,*rotb;
-struct hdkeyb *hdkeyb;
+//struct hdkeyb *hdkeyb;
 
 GPtrArray *rotars;
 MUTEX_DEFINE(rotars);
@@ -88,13 +88,17 @@ struct rotar *init_rotar(struct config_rotar *crot, int rotchar){
 				return NULL;
 			}
 			if (crot->rot_model > 0){
-				if (strchr(crot->rot_filename, '\\') != NULL){
-					safe_strncpy(rot->rot->state.rotport.pathname, crot->rot_filename, FILPATHLEN);
-				}else{
+#ifdef Z_MSC_MINGW_CYGWIN
+				if (strchr(crot->rot_filename, '\\') == NULL && z_strcasestr(crot->rot_filename, "COM") != NULL){
 					char *c = g_strdup_printf("\\\\.\\%s", crot->rot_filename);
 					safe_strncpy(rot->rot->state.rotport.pathname, c, FILPATHLEN);
 					g_free(c);
 				}
+				else
+#endif
+				{
+					safe_strncpy(rot->rot->state.rotport.pathname, crot->rot_filename, FILPATHLEN);
+				}
 			}
 
             rot->hl_azim = -1;
@@ -300,20 +304,21 @@ struct rotar *get_rotar_by_rotstr(char *rotstr){
 
 struct rotar *get_rotar_by_netid_rotstr(char *netid, char *rotstr){
     int i;
-    struct rotar *rot = NULL;
+    struct rotar *ret = NULL;
 
     if (!rotars) return NULL;
     MUTEX_LOCK(rotars);
     for (i=0;i<rotars->len;i++){
-        rot=(struct rotar *)g_ptr_array_index(rotars, i);
+        struct rotar *rot=(struct rotar *)g_ptr_array_index(rotars, i);
         //dbg("  rot->type=%d rotchar=%s netid=%s\n", rot->type, rot->rem_rotstr, rot->netid);
         if (rot->type != ROT_REMOTE) continue;
         if (strcmp(rot->netid, netid)!=0) continue;
         if (strcmp(rot->rem_rotstr, rotstr)!=0) continue;
+		ret = rot;
         break;
     }
     MUTEX_UNLOCK(rotars);
-    return rot;
+    return ret;
 }
 
 
