@@ -8,10 +8,10 @@
 
 */
 /* TODO
- I + Q = USB
- I - Q = LSB
- SQRT (I * I + Q * Q) = AM
- FM = atan(Q * I_old-I * Q_old, I * I_old+ Q * Q_old)
+ I + Q = USB
+ I - Q = LSB
+ SQRT (I * I + Q * Q) = AM
+ FM = atan(Q * I_old-I * Q_old, I * I_old+ Q * Q_old)
 */
 
 #include "header.h"
@@ -873,7 +873,7 @@ gpointer sdr_thread_func(gpointer data){
 	sdr->agc_period_ms = 1;
 	sdr->agc_n = sdr->samplerate * sdr->agc_period_ms / 1000.0;
 	sdr->agc_ign = sdr->samplerate * 100 / ( 1000.0 * sdr->agc_n); 
-	buf = g_new0(short, sdr->frames * sdr->iqdsp->channels); // nem bt sdr->samples?
+	buf = g_new0(short, sdr->frames * sdr->iqdsp->channels); // nemá být sdr->samples?
 
 	memset(sdr->iq, 0, sizeof(fftw_complex) * sdr->n);
 	gettimeofday(&tvstart, NULL);
