@@ -22,6 +22,7 @@ struct band;
 struct skedwin_data;
 struct zhttp;
 struct vhfcontestnet;
+struct slovhfnet;
 struct wiki;
 
 /* also used for ctest->cq->type */
@@ -97,8 +98,10 @@ struct session {
 	struct zosk *osk;
 #endif
 	struct vhfcontestnet *vcn;
+	struct slovhfnet *slovhf;
 	struct wiki *wiki;
 	double myh, myw;
+	char *callunder;
 };
 
 
@@ -123,6 +126,7 @@ void draw_time(void);
 void time_func(void *);
 void print_tucnak(int x, int y);
 void net_timer_redraw(void *);
+void clear_hicalls(void);
 int load_hicalls_from_file(char *filename);
 int save_hicalls_to_file(char *filename);
 void after_callsign(struct band *band,char *c, char *oldtmpqcall);
@@ -132,7 +136,7 @@ void after_nr(struct band *band,char *c);
 #ifdef FALL
 void fall_func(void *arg);
 #endif
-gboolean free_hicalls(gpointer key, gpointer value, gpointer user_data);
+//gboolean free_hicalls(gpointer key, gpointer value, gpointer user_data);
 void process_input_no_contest(void *enterdata, gchar *text, int cq);
 void update_hw(void);
 
