@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2015  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2020  Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -293,7 +293,7 @@ gpointer ssbd_play_thread_func(gpointer data){
     /*dbg("play thread started\n");
     for (i=0;i<6;i++){
         if (ssbd->thread_break)  goto x; 
-        dbg("kdák\n");
+        dbg("kdĂĄk\n");
         sleep(1);
     }
     */
@@ -389,7 +389,7 @@ gpointer ssbd_play_thread_func(gpointer data){
                 GString *gs = g_string_new("");
                 err=errno;
                 MUTEX_LOCK(ssbd);
-                g_string_sprintfa(gs, "!%s %s ", VTEXT(T_CANT_WRITE_TO), gssbd->dsp->name);
+                g_string_append_printf(gs, "!%s %s ", VTEXT(T_CANT_WRITE_TO), gssbd->dsp->name);
                 z_strerror(gs, err);
                 g_string_append_c(gs, '\n');
 				MUTEX_UNLOCK(ssbd);
@@ -657,9 +657,9 @@ gpointer ssbd_rec_thread_func(gpointer data){
             GString *gs = g_string_new("");
             err=errno;
             MUTEX_LOCK(ssbd);
-            g_string_sprintfa(gs, "!%s %s ", VTEXT(T_CANT_READ_FROM), gssbd->dsp->name);
+            g_string_append_printf(gs, "!%s %s ", VTEXT(T_CANT_READ_FROM), gssbd->dsp->name);
             z_strerror(gs, err);
-            g_string_sprintfa(gs, " %d %d\n", frames, err);
+            g_string_append_printf(gs, " %d %d\n", frames, err);
             MUTEX_UNLOCK(ssbd);
 			zselect_msg_send(zsel, "%s;%s", "SSBR", gs->str);
             g_string_free(gs, TRUE);
@@ -778,7 +778,7 @@ gpointer ssbd_rec_thread_func(gpointer data){
             GString *gs = g_string_new("");
             dbg("ssbd_rec_func write<=0\n"); 
             MUTEX_LOCK(ssbd);
-            g_string_sprintfa(gs, "!%s %s ", VTEXT(T_CANT_WRITE), gssbd->rfilename);
+            g_string_append_printf(gs, "!%s %s ", VTEXT(T_CANT_WRITE), gssbd->rfilename);
             z_strerror(gs, errno);
             g_string_append(gs, "\n");
             MUTEX_UNLOCK(ssbd);
