@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2015  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2020  Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -678,8 +678,8 @@ void redraw_stats(struct band *band){
     }    
     print_text(STATS_X,STATS_Y+2,term->x-QSONR_WIDTH-BAND_WIDTH-3,VTEXT(T_SES_STAT_TIT),COL_NORM);
 	gs = g_string_sized_new(100);
-	g_string_sprintfa(gs, "%4d  %6d  %4d  %4d   %4d  %7d ", nqsos, nqsop, nexcp, nwwlp, ndxcp, ntotal);
-	if (nqsos != 0) g_string_sprintfa(gs, "%6.1f", (double)ntotal/(double)nqsos);
+	g_string_append_printf(gs, "%4d  %6d  %4d  %4d   %4d  %7d ", nqsos, nqsop, nexcp, nwwlp, ndxcp, ntotal);
+	if (nqsos != 0) g_string_append_printf(gs, "%6.1f", (double)ntotal/(double)nqsos);
     print_text(STATS_X,STATS_Y+3,term->x-QSONR_WIDTH-BAND_WIDTH-3,gs->str,COL_NORM);
     g_string_free(gs, TRUE);
 
@@ -870,7 +870,7 @@ void add_sf_miss_excs(struct band *b){
             k = i+j*lines;
             if (k>=ms.ia->len) continue;
             c = (gchar *)z_ptr_array_index(ms.ia, k);
-            g_string_sprintfa(gs, "%-*s", ms.maxlen+1, c);        
+            g_string_append_printf(gs, "%-*s", ms.maxlen+1, c);        
         }
         fifo_addf(F, "%s", gs->str);
         g_string_truncate(gs, 0);
@@ -1007,7 +1007,7 @@ void add_sf_wkd_wwls(struct band *b){
                 g_string_append(gs, "     ");
                 continue;
             }
-            g_string_sprintfa(gs, " %s", s); 
+            g_string_append_printf(gs, " %s", s); 
             
         }
         fifo_addf(F, "%s", gs->str);
@@ -1050,9 +1050,9 @@ void add_sf_cnt_in_wwls(struct band *b){
 
             if ((cnt = (gint *)g_hash_table_lookup(b->stats->wwls, s))!=NULL){
                 if (aw==0 && ah==0){
-                    g_string_sprintfa(gs, ">%3d<", *cnt);
+                    g_string_append_printf(gs, ">%3d<", *cnt);
                 }else{
-                    g_string_sprintfa(gs, " %3d ", *cnt); 
+                    g_string_append_printf(gs, " %3d ", *cnt); 
                 }
                 continue;
             }
