@@ -7,6 +7,7 @@
     modify it under the terms of the GNU General Public License
     version 2 as published by the Free Software Foundation.
 
+    UTF-8 detect: ěščřžýáíé
 */
 
 #include <libzia.h>
@@ -1473,7 +1474,7 @@ void sw_qsos_redraw(struct subwin *sw, struct band *band, int flags){
         else unkcall=' ';
         sprintf(qtf,"%3d", q->qtf);
 #if defined(Z_HAVE_SDL) && !defined(Z_ANDROID)     
-//        if (sdl) strcat(qtf, "");
+//        if (sdl) strcat(qtf, "°");
         if (sdl) strcat(qtf, "\xb0");
 #endif
         safe_strncpy0(exc, q->exc, 5);
@@ -1486,12 +1487,20 @@ void sw_qsos_redraw(struct subwin *sw, struct band *band, int flags){
 //            dbg("bandname='%s'\n", q->band->bandname);
         }
         
-        c=g_strdup_printf("%10s %5s %-12s%c%5s%4s%5s%4s %-4s %-6s %c%c%6s %-4s%-5s %-7s %s",
+		char qrgstr[50];
+		if (q->qrg > 0){
+			z_qrg_format(qrgstr, 30, q->qrg);
+			strcat(qrgstr, " ");
+		}else{
+			strcpy(qrgstr, "");
+		}
+
+        c=g_strdup_printf("%10s %5s %-12s%c%5s%4s%5s%4s %-4s %-6s %c%c%6s %-4s%-5s %-7s %s%s",
                 dateband, dtime, call, suspcall, 
                 q->rsts, q->qsonrs, q->rstr, q->qsonrr,
                 exc, q->locator, susploc, unkcall,
                 qsop, *q->locator?qtf:"", new_, q->operator_,
-                q->remark);
+                qrgstr, q->remark);
 
 		if (index==sw->cur && !cfg->usetouch) fill_area(sw->x, sw->y+i-y0, sw->w, 1, COL_INV);
         if (strlen(c)>sw->ho) 
