@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2016  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2020  Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -28,8 +28,8 @@ static int rigerr = NOTHING;
 #define TRTR(thr, m...) if (cfg->trace_rig >= (thr ? 2 : 1)){ \
     GString *gs = g_string_new("RIG: "); \
     if (thr) g_string_append(gs, "        "); \
-	g_string_sprintfa(gs, m); \
-	if (rigerr != NOTHING) g_string_sprintfa(gs, ":      %s", trig_short_errstr(rigerr)); \
+	g_string_append_printf(gs, m); \
+	if (rigerr != NOTHING) g_string_append_printf(gs, ":      %s", trig_short_errstr(rigerr)); \
 	trace(1, "%s", gs->str); \
 	g_string_free(gs, TRUE); \
 }
@@ -37,8 +37,8 @@ static int rigerr = NOTHING;
 #define TRTR(thr, m, ...) if (cfg->trace_rig >= (thr ? 2 : 1)){ \
     GString *gs = g_string_new("RIG"); \
     if (thr) g_string_append(gs, "           "); \
-	g_string_sprintfa(gs, m, __VA_ARGS__); \
-	if (rigerr != NOTHING) g_string_sprintfa(gs, ":      %s", trig_short_errstr((enum rig_errcode_e)rigerr)); \
+	g_string_append_printf(gs, m, __VA_ARGS__); \
+	if (rigerr != NOTHING) g_string_append_printf(gs, ":      %s", trig_short_errstr((enum rig_errcode_e)rigerr)); \
 	trace(1, "%s", gs->str); \
 	g_string_free(gs, TRUE); \
 }
@@ -75,6 +75,7 @@ struct trig *get_trig_by_number(struct trigs *trigs, int nr){
 struct trigs *gtrigs;
 ZPtrArray *riglist = NULL;
 
+//static int rig_load_all_backends_called = 0;
 
 // ---------------- trigs functions
 void init_trigs(void){
@@ -97,7 +98,10 @@ void init_trigs(void){
 
     if (!riglist){
         riglist = z_ptr_array_new();
-        rig_load_all_backends();
+		//if (!rig_load_all_backends_called){
+			rig_load_all_backends();
+		//	rig_load_all_backends_called = 1;
+		//}
         rig_list_foreach(trig_save_riglist, riglist);
         z_ptr_array_qsort(riglist, trig_compare);
 #if 0
@@ -125,8 +129,8 @@ void free_trigs(struct trigs *trigs){
     
     if (riglist){
         z_ptr_array_free(riglist, TRUE);
-        riglist = NULL;
     }
+        riglist = NULL;
 
 	for (i = 0; i < trigs->trigs->len; i++){
 		struct trig *trig = (struct trig *)g_ptr_array_index(trigs->trigs, i);
