@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2015  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2020  Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -263,15 +263,15 @@ void sdl_pre_info(){
 
     vi = SDL_GetVideoInfo();
     if (!vi){
-        g_string_sprintfa(gs, "No \"best mode\" exists\n");
+        g_string_append_printf(gs, "No \"best mode\" exists\n");
     }else{
-        g_string_sprintfa(gs, "Screen: %dx%d-%d ", vi->current_w, vi->current_h, vi->vfmt->BitsPerPixel);
+        g_string_append_printf(gs, "Screen: %dx%d-%d ", vi->current_w, vi->current_h, vi->vfmt->BitsPerPixel);
         if (vi->vfmt->palette){
-            g_string_sprintfa(gs, "using palette ");
+            g_string_append_printf(gs, "using palette ");
         }else{
-            g_string_sprintfa(gs, "R=%x G=%x B=%x A=%x ", vi->vfmt->Rmask, vi->vfmt->Gmask, vi->vfmt->Bmask, vi->vfmt->Amask);
+            g_string_append_printf(gs, "R=%x G=%x B=%x A=%x ", vi->vfmt->Rmask, vi->vfmt->Gmask, vi->vfmt->Bmask, vi->vfmt->Amask);
         }
-        g_string_sprintfa(gs, "colorkey=%04x alpha=%d\n", vi->vfmt->colorkey, vi->vfmt->alpha);
+        g_string_append_printf(gs, "colorkey=%04x alpha=%d\n", vi->vfmt->colorkey, vi->vfmt->alpha);
     }
 	g_free(sdl_best);
 	sdl_best = g_strdup(gs->str);
@@ -284,41 +284,41 @@ void sdl_info(GString *gs){
     char str[256];
     int oldw, oldh;
 
-    g_string_sprintfa(gs, "\n  sdl_info:\n");
+    g_string_append_printf(gs, "\n  sdl_info:\n");
 
 
     if (SDL_Init(SDL_INIT_VIDEO) < 0){
-        g_string_sprintfa(gs, "SDL_Init failed\n");
+        g_string_append_printf(gs, "SDL_Init failed\n");
         return;
     };
     
     SDL_VideoDriverName(str, sizeof(str)-1);
     str[sizeof(str)-1]='\0';
-    if (*str) g_string_sprintfa(gs, "Driver: %s\n", str);
+    if (*str) g_string_append_printf(gs, "Driver: %s\n", str);
 
 	if (!sdl_best) sdl_pre_info();
     g_string_append(gs, sdl_best);
     
     modes=SDL_ListModes(NULL, SDL_FULLSCREEN);
     if (!modes) {
-        g_string_sprintfa(gs, "No video modes available (SDL_ListModes)\n");
+        g_string_append_printf(gs, "No video modes available (SDL_ListModes)\n");
     }else{
         if (modes==(SDL_Rect**)-1){
-            g_string_sprintfa(gs, "All resolutinons available\n");
+            g_string_append_printf(gs, "All resolutinons available\n");
             return;
         }
         
-		g_string_sprintfa(gs, "Modes:  ");
+		g_string_append_printf(gs, "Modes:  ");
         oldw=oldh=-1;
         for (i=0;modes[i];i++){
             if (modes[i]->w==oldw && modes[i]->h==oldh) continue;
-            g_string_sprintfa(gs, "%dx%d ", modes[i]->w, modes[i]->h);
+            g_string_append_printf(gs, "%dx%d ", modes[i]->w, modes[i]->h);
             oldw=modes[i]->w;
             oldh=modes[i]->h;
         }
-	    g_string_sprintfa(gs, "\n");
+	    g_string_append_printf(gs, "\n");
     }
-	g_string_sprintfa(gs, "\n");
+	g_string_append_printf(gs, "\n");
 }
 
 
@@ -491,7 +491,7 @@ void sdl_redraw_screen(void){
     }
     gettimeofday(&startx, NULL);
 #endif
-	// TODO pi ukonovn pod msvc tady nkdy je term == NULL
+	// TODO při ukončování pod msvc tady někdy je term == NULL
     minx=term->x;
     miny=term->y;
     maxx=-1;
