@@ -1,6 +1,6 @@
 /*
     Tucnak - VHF contest log
-    Copyright (C) 2002-2015  Ladislav Vaiz <ok1zia@nagano.cz>
+    Copyright (C) 2002-2020  Ladislav Vaiz <ok1zia@nagano.cz>
 
     This program is free software; you can redistribute it and/or
     modify it under the terms of the GNU General Public License
@@ -61,7 +61,7 @@ void wiki_header(GString *gs){
     
     zg_string_eprintfa("w", gs, "=%s=\n", ctest->tname);
 
-    g_string_sprintfa(gs, "{| style=\"background-color:#ffffcc;\"\n");
+    g_string_append_printf(gs, "{| style=\"background-color:#ffffcc;\"\n");
     zg_string_eprintfa("w", gs, "|-\n|%s||%S\n", VTEXT(T_CALL2), ctest->pcall);
     zg_string_eprintfa("w", gs, "|-\n|%s||%S\n", VTEXT(T_WWL2), ctest->pwwlo);
     if (ctest->padr1 && *ctest->padr1)
@@ -70,8 +70,8 @@ void wiki_header(GString *gs){
         zg_string_eprintfa("w", gs, "|-\n| ||%s\n", ctest->padr2);
 
     i = atoi(ctest->cdate);
-    g_string_sprintfa(gs, "|-\n|%s||%d.%d.%d\n", VTEXT(T_DATE3), i % 100, (i / 100) % 100, i / 10000);
-    g_string_sprintfa(gs, "|}\n");
+    g_string_append_printf(gs, "|-\n|%s||%d.%d.%d\n", VTEXT(T_DATE3), i % 100, (i / 100) % 100, i / 10000);
+    g_string_append_printf(gs, "|}\n");
 }
 
 
@@ -150,7 +150,7 @@ void wiki_band_header(GString *gs, struct band *band, int flags){
 #endif
 	if (chart) sw_chart_recalc_extremes(chart, aband);
 
-    g_string_sprintfa(gs, "\n\n=Band %s=\n", band->bandname);
+    g_string_append_printf(gs, "\n\n=Band %s=\n", band->bandname);
 
     ntotal = band->stats->ntotal;
     if (ntotal < 10000){
@@ -158,14 +158,14 @@ void wiki_band_header(GString *gs, struct band *band, int flags){
     }else{
         ntotal = ( ntotal / 1000 ) * 1000;
     }
-    g_string_sprintfa(gs, "{| style=\"background-color:#ffffcc;\"\n");
-    g_string_sprintfa(gs, "|+ %s\n", band->bandname);
-    g_string_sprintfa(gs, "|-\n|%s||%d\n", VTEXT(T_QSOS2), band->stats->nqsos);
-    g_string_sprintfa(gs, "|-\n|%s||%d\n", VTEXT(T_POINTS2), ntotal);
-    g_string_sprintfa(gs, "|-\n|%s||%d\n", VTEXT(T_WWLS), g_hash_table_size(band->stats->wwls));
-    g_string_sprintfa(gs, "|-\n|%s||%d\n", VTEXT(T_DXCCS), g_hash_table_size(band->stats->dxcs));
-    g_string_sprintfa(gs, "|-\n|%s||%d %s\n", VTEXT(T_AVG2), band->stats->ntotal/band->stats->nqsos, VTEXT(T_PTSQSO));
-    g_string_sprintfa(gs, "|}\n");
+    g_string_append_printf(gs, "{| style=\"background-color:#ffffcc;\"\n");
+    g_string_append_printf(gs, "|+ %s\n", band->bandname);
+    g_string_append_printf(gs, "|-\n|%s||%d\n", VTEXT(T_QSOS2), band->stats->nqsos);
+    g_string_append_printf(gs, "|-\n|%s||%d\n", VTEXT(T_POINTS2), ntotal);
+    g_string_append_printf(gs, "|-\n|%s||%d\n", VTEXT(T_WWLS), g_hash_table_size(band->stats->wwls));
+    g_string_append_printf(gs, "|-\n|%s||%d\n", VTEXT(T_DXCCS), g_hash_table_size(band->stats->dxcs));
+    g_string_append_printf(gs, "|-\n|%s||%d %s\n", VTEXT(T_AVG2), band->stats->ntotal/band->stats->nqsos, VTEXT(T_PTSQSO));
+    g_string_append_printf(gs, "|}\n");
 
 	/* top 10 */
 
@@ -205,52 +205,52 @@ void wiki_band_header(GString *gs, struct band *band, int flags){
 		}
 	}
 
-    g_string_sprintfa(gs, "\n\n");
+    g_string_append_printf(gs, "\n\n");
 
 
     //tabulka kolem
 
-    g_string_sprintfa(gs, "{| cellpadding=\"10\" style=\"background: transparent;\"\n");
-    g_string_sprintfa(gs, "|\n");
+    g_string_append_printf(gs, "{| cellpadding=\"10\" style=\"background: transparent;\"\n");
+    g_string_append_printf(gs, "|\n");
 
-    g_string_sprintfa(gs, "{| cellpadding=\"5\" style=\"background-color:#ffffcc;\"\n");
-    g_string_sprintfa(gs, "|+ %s\n", VTEXT(T_TOP_10_CALLS));
-    g_string_sprintfa(gs, "!%s!!%s!!%s!!%s\n", VTEXT(T_CALL), VTEXT(T_QRB), VTEXT(T_OPERATOR2), VTEXT(T_MODE2));
+    g_string_append_printf(gs, "{| cellpadding=\"5\" style=\"background-color:#ffffcc;\"\n");
+    g_string_append_printf(gs, "|+ %s\n", VTEXT(T_TOP_10_CALLS));
+    g_string_append_printf(gs, "!%s!!%s!!%s!!%s\n", VTEXT(T_CALL), VTEXT(T_QRB), VTEXT(T_OPERATOR2), VTEXT(T_MODE2));
 	for (i = 0; i < TOPS_NUM && i < band->qsos->len && top[i]; i++) {
 		q = top[i];
-		g_string_sprintfa(gs, "|-\n|%s||align=\"right\"|%4u km||%s||%s\n", q->callsign, (int) q->qrb, q->operator_, mode_msg[q->mode]);
+		g_string_append_printf(gs, "|-\n|%s||align=\"right\"|%4u km||%s||%s\n", q->callsign, (int) q->qrb, q->operator_, mode_msg[q->mode]);
 	}
 
-    g_string_sprintfa(gs, "|}\n");
+    g_string_append_printf(gs, "|}\n");
 
     ia = z_ptr_array_new();
     g_hash_table_foreach(band->stats->wwls, wiki_wwl_func, ia);
     z_ptr_array_qsort(ia, wiki_compare_colon_int);
     
-    g_string_sprintfa(gs, "|\n");
+    g_string_append_printf(gs, "|\n");
 
-    g_string_sprintfa(gs, "{| cellpadding=\"5\" style=\"background-color:#ffffcc;\"\n");
-    g_string_sprintfa(gs, "|+ %s\n", VTEXT(T_TOP_10_WWLS));
-    g_string_sprintfa(gs, "!%s!!%s!!%s\n", VTEXT(T_WWL3), VTEXT(T_POINTS), VTEXT(T_SW_QSOS));
+    g_string_append_printf(gs, "{| cellpadding=\"5\" style=\"background-color:#ffffcc;\"\n");
+    g_string_append_printf(gs, "|+ %s\n", VTEXT(T_TOP_10_WWLS));
+    g_string_append_printf(gs, "!%s!!%s!!%s\n", VTEXT(T_WWL3), VTEXT(T_POINTS), VTEXT(T_SW_QSOS));
     for (i = 0; i < ia->len && i < 10; i++){
         c = (gchar *)z_ptr_array_index(ia, i);
-		g_string_sprintfa(gs, "|-\n|%s\n", c);
+		g_string_append_printf(gs, "|-\n|%s\n", c);
     }
 
-    g_string_sprintfa(gs, "|}\n");
+    g_string_append_printf(gs, "|}\n");
     z_ptr_array_free_all(ia);
 
-    g_string_sprintfa(gs, "|}\n\n");
+    g_string_append_printf(gs, "|}\n\n");
 
 #ifdef Z_HAVE_SDL
 	if (map && map->screen){
-		g_string_sprintfa(gs, "[[File:map_%s_%s_%c.png|border|%dpx|%s %s %s]]\n\n", 
+		g_string_append_printf(gs, "[[File:map_%s_%s_%c.png|border|%dpx|%s %s %s]]\n\n", 
 			ctest->pcall, ctest->cdate, z_char_lc(band->bandchar), map->screen->w,
 			ctest->pcall, ctest->tname, band->bandname);
 	}
 
 	if (chart && chart->screen){
-		g_string_sprintfa(gs, "[[File:chart_%s_%s_%c.png|border|%dpx|%s %s %s]]\n\n", 
+		g_string_append_printf(gs, "[[File:chart_%s_%s_%c.png|border|%dpx|%s %s %s]]\n\n", 
 			ctest->pcall, ctest->cdate, z_char_lc(band->bandchar), chart->screen->w, 
 			ctest->pcall, ctest->tname, band->bandname);
 	}
@@ -259,7 +259,7 @@ void wiki_band_header(GString *gs, struct band *band, int flags){
 }
 
 void wiki_footer(GString *gs){
-    g_string_sprintfa(gs, "\n\nCreated by [http://tucnak.nagano.cz Tucnak ver. %s]\n", VERSION_STRING);
+    g_string_append_printf(gs, "\n\nCreated by [http://tucnak.nagano.cz Tucnak ver. %s]\n", VERSION_STRING);
 }
 
 
@@ -763,7 +763,7 @@ void wiki_info(void *arg1){
 		r->timer = -1;
 
 		gs = g_string_new("");
-		if (gses->wiki->status != NULL) g_string_sprintfa(gs, "%s", gses->wiki->status);
+		if (gses->wiki->status != NULL) g_string_append_printf(gs, "%s", gses->wiki->status);
 		if (gses->wiki->status != NULL && gses->wiki->http != NULL) g_string_append(gs, "\n\n");
 		if (gses->wiki->http != NULL){
 			g_string_append(gs, VTEXT(T_HTTP_STATUS));
