@@ -102,6 +102,7 @@ struct zosk *zosk_init(SDL_Surface *screen, int flags, const char *text){
 	int h = screen->h;
     int spypeers = 0;
 
+    //dbg("zosk_init(%d, '%s')\n", flags, text);
 	zosk = g_new0(struct zosk, 1);
 
     w -= 10;
@@ -200,7 +201,6 @@ struct zosk *zosk_init(SDL_Surface *screen, int flags, const char *text){
     zosk_key_add(zosk, 2, SDLK_PERIOD, (SDLKey)'|', SDLK_UNKNOWN);
 	zosk_key_add(zosk, 2, SDLK_SLASH, SDLK_BACKSLASH, SDLK_UNKNOWN);
     zosk_key_add(zosk, 3, SDLK_RETURN, SDLK_UNKNOWN, SDLK_UNKNOWN);
-    
     return zosk;
 }
 
@@ -258,7 +258,7 @@ void zosk_draw_key_text(struct zosk *zosk, struct zosk_key *key){
 				key->cx - (int)(0.8 * fh), key->cy, color);
 			zsdl_printf(zosk->surface, key->cx + (int)(0.1 * fh), key->cy - 1, zosk->bbg, 0, 
 				ZFONT_CENTERX | ZFONT_CENTERY | ZFONT_TRANSP | ZFONT_USERH(fh),
-				"\xd7");
+				"x");
 			break;
 		case SDLK_TAB:    
 			z_line(zosk->surface, key->cx - (int)(0.5 * fh), key->cy-1, key->cx + (int)(0.2 * fh), key->cy-1, color);
@@ -467,7 +467,6 @@ void zosk_draw(struct zosk *zosk){
 	SDL_Rect r;
 	char *c;
 
-	//dbg("zosk_draw(%p %p)\n", zosk, zosk->surface);
 	SDL_FillRect(zosk->surface, NULL, zosk->bg);
 	
     r.x = 32;
@@ -485,7 +484,7 @@ void zosk_draw(struct zosk *zosk){
 	r.x = zosk->surface->w - r.w - 2;
 	r.y = 2;
 	SDL_FillRect(zosk->surface, &r, z_makecol(192, 192, 192));
-	zsdl_printf(zosk->surface, r.x + r.w/2, r.y + r.h / 2, z_makecol(0, 0, 0), 0, ZFONT_CENTERX | ZFONT_CENTERY | ZFONT_TRANSP | ZFONT_USERH(zosk->font_h), "\xd7");
+	zsdl_printf(zosk->surface, r.x + r.w/2, r.y + r.h / 2, z_makecol(0, 0, 0), 0, ZFONT_CENTERX | ZFONT_CENTERY | ZFONT_TRANSP | ZFONT_USERH(zosk->font_h), "x");
 
 	for (i = 0; i < zosk->keys->len; i++){
         struct zosk_key *key = (struct zosk_key *)g_ptr_array_index(zosk->keys, i);  
@@ -495,7 +494,6 @@ void zosk_draw(struct zosk *zosk){
 		zosk_draw_key(zosk, key, color);
 		if (key == zosk->active && key->pressed != 2) zosk_draw_top(zosk, key);
     }
-
 }
 
 int zosk_send(struct zosk *zosk){
